# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAutonomousDatabaseRefreshableClonesResult',
    'AwaitableGetAutonomousDatabaseRefreshableClonesResult',
    'get_autonomous_database_refreshable_clones',
    'get_autonomous_database_refreshable_clones_output',
]

@pulumi.output_type
class GetAutonomousDatabaseRefreshableClonesResult:
    """
    A collection of values returned by getAutonomousDatabaseRefreshableClones.
    """
    def __init__(__self__, autonomous_database_id=None, filters=None, id=None, refreshable_clone_collections=None):
        if autonomous_database_id and not isinstance(autonomous_database_id, str):
            raise TypeError("Expected argument 'autonomous_database_id' to be a str")
        pulumi.set(__self__, "autonomous_database_id", autonomous_database_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if refreshable_clone_collections and not isinstance(refreshable_clone_collections, list):
            raise TypeError("Expected argument 'refreshable_clone_collections' to be a list")
        pulumi.set(__self__, "refreshable_clone_collections", refreshable_clone_collections)

    @property
    @pulumi.getter(name="autonomousDatabaseId")
    def autonomous_database_id(self) -> str:
        return pulumi.get(self, "autonomous_database_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAutonomousDatabaseRefreshableClonesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="refreshableCloneCollections")
    def refreshable_clone_collections(self) -> Sequence['outputs.GetAutonomousDatabaseRefreshableClonesRefreshableCloneCollectionResult']:
        """
        The list of refreshable_clone_collection.
        """
        return pulumi.get(self, "refreshable_clone_collections")


class AwaitableGetAutonomousDatabaseRefreshableClonesResult(GetAutonomousDatabaseRefreshableClonesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAutonomousDatabaseRefreshableClonesResult(
            autonomous_database_id=self.autonomous_database_id,
            filters=self.filters,
            id=self.id,
            refreshable_clone_collections=self.refreshable_clone_collections)


def get_autonomous_database_refreshable_clones(autonomous_database_id: Optional[str] = None,
                                               filters: Optional[Sequence[pulumi.InputType['GetAutonomousDatabaseRefreshableClonesFilterArgs']]] = None,
                                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAutonomousDatabaseRefreshableClonesResult:
    """
    This data source provides the list of Autonomous Database Refreshable Clones in Oracle Cloud Infrastructure Database service.

    Lists the OCIDs of the Autonomous Database local and connected remote refreshable clones with the region where they exist for the specified source database.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_autonomous_database_refreshable_clones = oci.Database.get_autonomous_database_refreshable_clones(autonomous_database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str autonomous_database_id: The database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    __args__ = dict()
    __args__['autonomousDatabaseId'] = autonomous_database_id
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Database/getAutonomousDatabaseRefreshableClones:getAutonomousDatabaseRefreshableClones', __args__, opts=opts, typ=GetAutonomousDatabaseRefreshableClonesResult).value

    return AwaitableGetAutonomousDatabaseRefreshableClonesResult(
        autonomous_database_id=__ret__.autonomous_database_id,
        filters=__ret__.filters,
        id=__ret__.id,
        refreshable_clone_collections=__ret__.refreshable_clone_collections)


@_utilities.lift_output_func(get_autonomous_database_refreshable_clones)
def get_autonomous_database_refreshable_clones_output(autonomous_database_id: Optional[pulumi.Input[str]] = None,
                                                      filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAutonomousDatabaseRefreshableClonesFilterArgs']]]]] = None,
                                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAutonomousDatabaseRefreshableClonesResult]:
    """
    This data source provides the list of Autonomous Database Refreshable Clones in Oracle Cloud Infrastructure Database service.

    Lists the OCIDs of the Autonomous Database local and connected remote refreshable clones with the region where they exist for the specified source database.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_autonomous_database_refreshable_clones = oci.Database.get_autonomous_database_refreshable_clones(autonomous_database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str autonomous_database_id: The database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    ...
