# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetFusionEnvironmentFamilySubscriptionDetailResult',
    'AwaitableGetFusionEnvironmentFamilySubscriptionDetailResult',
    'get_fusion_environment_family_subscription_detail',
    'get_fusion_environment_family_subscription_detail_output',
]

@pulumi.output_type
class GetFusionEnvironmentFamilySubscriptionDetailResult:
    """
    A collection of values returned by getFusionEnvironmentFamilySubscriptionDetail.
    """
    def __init__(__self__, fusion_environment_family_id=None, id=None, subscriptions=None):
        if fusion_environment_family_id and not isinstance(fusion_environment_family_id, str):
            raise TypeError("Expected argument 'fusion_environment_family_id' to be a str")
        pulumi.set(__self__, "fusion_environment_family_id", fusion_environment_family_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if subscriptions and not isinstance(subscriptions, list):
            raise TypeError("Expected argument 'subscriptions' to be a list")
        pulumi.set(__self__, "subscriptions", subscriptions)

    @property
    @pulumi.getter(name="fusionEnvironmentFamilyId")
    def fusion_environment_family_id(self) -> str:
        return pulumi.get(self, "fusion_environment_family_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def subscriptions(self) -> Sequence['outputs.GetFusionEnvironmentFamilySubscriptionDetailSubscriptionResult']:
        """
        List of subscriptions.
        """
        return pulumi.get(self, "subscriptions")


class AwaitableGetFusionEnvironmentFamilySubscriptionDetailResult(GetFusionEnvironmentFamilySubscriptionDetailResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFusionEnvironmentFamilySubscriptionDetailResult(
            fusion_environment_family_id=self.fusion_environment_family_id,
            id=self.id,
            subscriptions=self.subscriptions)


def get_fusion_environment_family_subscription_detail(fusion_environment_family_id: Optional[str] = None,
                                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFusionEnvironmentFamilySubscriptionDetailResult:
    """
    This data source provides details about a specific Fusion Environment Family Subscription Detail resource in Oracle Cloud Infrastructure Fusion Apps service.

    Gets the subscription details of an fusion environment family.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fusion_environment_family_subscription_detail = oci.Functions.get_fusion_environment_family_subscription_detail(fusion_environment_family_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fusion_environment_family_id: The unique identifier (OCID) of the FusionEnvironmentFamily.
    """
    __args__ = dict()
    __args__['fusionEnvironmentFamilyId'] = fusion_environment_family_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Functions/getFusionEnvironmentFamilySubscriptionDetail:getFusionEnvironmentFamilySubscriptionDetail', __args__, opts=opts, typ=GetFusionEnvironmentFamilySubscriptionDetailResult).value

    return AwaitableGetFusionEnvironmentFamilySubscriptionDetailResult(
        fusion_environment_family_id=__ret__.fusion_environment_family_id,
        id=__ret__.id,
        subscriptions=__ret__.subscriptions)


@_utilities.lift_output_func(get_fusion_environment_family_subscription_detail)
def get_fusion_environment_family_subscription_detail_output(fusion_environment_family_id: Optional[pulumi.Input[str]] = None,
                                                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetFusionEnvironmentFamilySubscriptionDetailResult]:
    """
    This data source provides details about a specific Fusion Environment Family Subscription Detail resource in Oracle Cloud Infrastructure Fusion Apps service.

    Gets the subscription details of an fusion environment family.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fusion_environment_family_subscription_detail = oci.Functions.get_fusion_environment_family_subscription_detail(fusion_environment_family_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fusion_environment_family_id: The unique identifier (OCID) of the FusionEnvironmentFamily.
    """
    ...
