# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAgentImagesResult',
    'AwaitableGetAgentImagesResult',
    'get_agent_images',
    'get_agent_images_output',
]

@pulumi.output_type
class GetAgentImagesResult:
    """
    A collection of values returned by getAgentImages.
    """
    def __init__(__self__, agent_image_collections=None, filters=None, id=None):
        if agent_image_collections and not isinstance(agent_image_collections, list):
            raise TypeError("Expected argument 'agent_image_collections' to be a list")
        pulumi.set(__self__, "agent_image_collections", agent_image_collections)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="agentImageCollections")
    def agent_image_collections(self) -> Sequence['outputs.GetAgentImagesAgentImageCollectionResult']:
        """
        The list of agent_image_collection.
        """
        return pulumi.get(self, "agent_image_collections")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAgentImagesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetAgentImagesResult(GetAgentImagesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAgentImagesResult(
            agent_image_collections=self.agent_image_collections,
            filters=self.filters,
            id=self.id)


def get_agent_images(filters: Optional[Sequence[pulumi.InputType['GetAgentImagesFilterArgs']]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAgentImagesResult:
    """
    This data source provides the list of Agent Images in Oracle Cloud Infrastructure Database Migration service.

    Get details of the ODMS Agent Images available to install on-premises.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_agent_images = oci.DatabaseMigration.get_agent_images()
    ```
    """
    __args__ = dict()
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DatabaseMigration/getAgentImages:getAgentImages', __args__, opts=opts, typ=GetAgentImagesResult).value

    return AwaitableGetAgentImagesResult(
        agent_image_collections=__ret__.agent_image_collections,
        filters=__ret__.filters,
        id=__ret__.id)


@_utilities.lift_output_func(get_agent_images)
def get_agent_images_output(filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAgentImagesFilterArgs']]]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAgentImagesResult]:
    """
    This data source provides the list of Agent Images in Oracle Cloud Infrastructure Database Migration service.

    Get details of the ODMS Agent Images available to install on-premises.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_agent_images = oci.DatabaseMigration.get_agent_images()
    ```
    """
    ...
