# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDbSystemStoragePerformancesResult',
    'AwaitableGetDbSystemStoragePerformancesResult',
    'get_db_system_storage_performances',
    'get_db_system_storage_performances_output',
]

@pulumi.output_type
class GetDbSystemStoragePerformancesResult:
    """
    A collection of values returned by getDbSystemStoragePerformances.
    """
    def __init__(__self__, db_system_storage_performances=None, filters=None, id=None, shape_type=None, storage_management=None):
        if db_system_storage_performances and not isinstance(db_system_storage_performances, list):
            raise TypeError("Expected argument 'db_system_storage_performances' to be a list")
        pulumi.set(__self__, "db_system_storage_performances", db_system_storage_performances)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if shape_type and not isinstance(shape_type, str):
            raise TypeError("Expected argument 'shape_type' to be a str")
        pulumi.set(__self__, "shape_type", shape_type)
        if storage_management and not isinstance(storage_management, str):
            raise TypeError("Expected argument 'storage_management' to be a str")
        pulumi.set(__self__, "storage_management", storage_management)

    @property
    @pulumi.getter(name="dbSystemStoragePerformances")
    def db_system_storage_performances(self) -> Sequence['outputs.GetDbSystemStoragePerformancesDbSystemStoragePerformanceResult']:
        """
        The list of db_system_storage_performances.
        """
        return pulumi.get(self, "db_system_storage_performances")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetDbSystemStoragePerformancesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="shapeType")
    def shape_type(self) -> Optional[str]:
        """
        ShapeType of the DbSystems,INTEL or AMD
        """
        return pulumi.get(self, "shape_type")

    @property
    @pulumi.getter(name="storageManagement")
    def storage_management(self) -> str:
        return pulumi.get(self, "storage_management")


class AwaitableGetDbSystemStoragePerformancesResult(GetDbSystemStoragePerformancesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDbSystemStoragePerformancesResult(
            db_system_storage_performances=self.db_system_storage_performances,
            filters=self.filters,
            id=self.id,
            shape_type=self.shape_type,
            storage_management=self.storage_management)


def get_db_system_storage_performances(filters: Optional[Sequence[pulumi.InputType['GetDbSystemStoragePerformancesFilterArgs']]] = None,
                                       shape_type: Optional[str] = None,
                                       storage_management: Optional[str] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDbSystemStoragePerformancesResult:
    """
    This data source provides the list of Db System Storage Performances in Oracle Cloud Infrastructure Database service.

    Gets a list of possible expected storage performance parameters of a VMDB System based on Configuration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_db_system_storage_performances = oci.Database.get_db_system_storage_performances(storage_management=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        shape_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str shape_type: Optional. Filters the performance results by shape type.
    :param str storage_management: The DB system storage management option. Used to list database versions available for that storage manager. Valid values are `ASM` and `LVM`.
           * ASM specifies Oracle Automatic Storage Management
           * LVM specifies logical volume manager, sometimes called logical disk manager.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['shapeType'] = shape_type
    __args__['storageManagement'] = storage_management
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Database/getDbSystemStoragePerformances:getDbSystemStoragePerformances', __args__, opts=opts, typ=GetDbSystemStoragePerformancesResult).value

    return AwaitableGetDbSystemStoragePerformancesResult(
        db_system_storage_performances=__ret__.db_system_storage_performances,
        filters=__ret__.filters,
        id=__ret__.id,
        shape_type=__ret__.shape_type,
        storage_management=__ret__.storage_management)


@_utilities.lift_output_func(get_db_system_storage_performances)
def get_db_system_storage_performances_output(filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetDbSystemStoragePerformancesFilterArgs']]]]] = None,
                                              shape_type: Optional[pulumi.Input[Optional[str]]] = None,
                                              storage_management: Optional[pulumi.Input[str]] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDbSystemStoragePerformancesResult]:
    """
    This data source provides the list of Db System Storage Performances in Oracle Cloud Infrastructure Database service.

    Gets a list of possible expected storage performance parameters of a VMDB System based on Configuration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_db_system_storage_performances = oci.Database.get_db_system_storage_performances(storage_management=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        shape_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str shape_type: Optional. Filters the performance results by shape type.
    :param str storage_management: The DB system storage management option. Used to list database versions available for that storage manager. Valid values are `ASM` and `LVM`.
           * ASM specifies Oracle Automatic Storage Management
           * LVM specifies logical volume manager, sometimes called logical disk manager.
    """
    ...
