# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetKnowledgebasesResult',
    'AwaitableGetKnowledgebasesResult',
    'get_knowledgebases',
    'get_knowledgebases_output',
]

@pulumi.output_type
class GetKnowledgebasesResult:
    """
    A collection of values returned by getKnowledgebases.
    """
    def __init__(__self__, compartment_id=None, display_name=None, filters=None, id=None, knowledge_base_collections=None, state=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if knowledge_base_collections and not isinstance(knowledge_base_collections, list):
            raise TypeError("Expected argument 'knowledge_base_collections' to be a list")
        pulumi.set(__self__, "knowledge_base_collections", knowledge_base_collections)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[str]:
        """
        The Oracle Cloud Identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the Knowledge Base's compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The name of the Knowledge Base.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetKnowledgebasesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The Oracle Cloud Identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="knowledgeBaseCollections")
    def knowledge_base_collections(self) -> Sequence['outputs.GetKnowledgebasesKnowledgeBaseCollectionResult']:
        """
        The list of knowledge_base_collection.
        """
        return pulumi.get(self, "knowledge_base_collections")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current lifecycle state of the Knowledge Base.
        """
        return pulumi.get(self, "state")


class AwaitableGetKnowledgebasesResult(GetKnowledgebasesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKnowledgebasesResult(
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            knowledge_base_collections=self.knowledge_base_collections,
            state=self.state)


def get_knowledgebases(compartment_id: Optional[str] = None,
                       display_name: Optional[str] = None,
                       filters: Optional[Sequence[pulumi.InputType['GetKnowledgebasesFilterArgs']]] = None,
                       id: Optional[str] = None,
                       state: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKnowledgebasesResult:
    """
    This data source provides the list of Knowledge Bases in Oracle Cloud Infrastructure ADM service.

    Returns a list of KnowledgeBases based on the specified query parameters.
    At least id or compartmentId query parameter must be provided.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_knowledge_bases = oci.Adm.get_knowledgebases(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: A filter to return only resources that belong to the specified compartment identifier.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str id: A filter to return only resources that match the specified identifier.
    :param str state: A filter to return only Knowledge Bases that match the specified lifecycleState.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['id'] = id
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Adm/getKnowledgebases:getKnowledgebases', __args__, opts=opts, typ=GetKnowledgebasesResult).value

    return AwaitableGetKnowledgebasesResult(
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        knowledge_base_collections=__ret__.knowledge_base_collections,
        state=__ret__.state)


@_utilities.lift_output_func(get_knowledgebases)
def get_knowledgebases_output(compartment_id: Optional[pulumi.Input[Optional[str]]] = None,
                              display_name: Optional[pulumi.Input[Optional[str]]] = None,
                              filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetKnowledgebasesFilterArgs']]]]] = None,
                              id: Optional[pulumi.Input[Optional[str]]] = None,
                              state: Optional[pulumi.Input[Optional[str]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetKnowledgebasesResult]:
    """
    This data source provides the list of Knowledge Bases in Oracle Cloud Infrastructure ADM service.

    Returns a list of KnowledgeBases based on the specified query parameters.
    At least id or compartmentId query parameter must be provided.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_knowledge_bases = oci.Adm.get_knowledgebases(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: A filter to return only resources that belong to the specified compartment identifier.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str id: A filter to return only resources that match the specified identifier.
    :param str state: A filter to return only Knowledge Bases that match the specified lifecycleState.
    """
    ...
