# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetFusionEnvironmentDataMaskingActivitiesResult',
    'AwaitableGetFusionEnvironmentDataMaskingActivitiesResult',
    'get_fusion_environment_data_masking_activities',
    'get_fusion_environment_data_masking_activities_output',
]

@pulumi.output_type
class GetFusionEnvironmentDataMaskingActivitiesResult:
    """
    A collection of values returned by getFusionEnvironmentDataMaskingActivities.
    """
    def __init__(__self__, data_masking_activity_collections=None, filters=None, fusion_environment_id=None, id=None, state=None):
        if data_masking_activity_collections and not isinstance(data_masking_activity_collections, list):
            raise TypeError("Expected argument 'data_masking_activity_collections' to be a list")
        pulumi.set(__self__, "data_masking_activity_collections", data_masking_activity_collections)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if fusion_environment_id and not isinstance(fusion_environment_id, str):
            raise TypeError("Expected argument 'fusion_environment_id' to be a str")
        pulumi.set(__self__, "fusion_environment_id", fusion_environment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="dataMaskingActivityCollections")
    def data_masking_activity_collections(self) -> Sequence['outputs.GetFusionEnvironmentDataMaskingActivitiesDataMaskingActivityCollectionResult']:
        """
        The list of data_masking_activity_collection.
        """
        return pulumi.get(self, "data_masking_activity_collections")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetFusionEnvironmentDataMaskingActivitiesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter(name="fusionEnvironmentId")
    def fusion_environment_id(self) -> str:
        """
        Fusion Environment Identifier.
        """
        return pulumi.get(self, "fusion_environment_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the DataMaskingActivity.
        """
        return pulumi.get(self, "state")


class AwaitableGetFusionEnvironmentDataMaskingActivitiesResult(GetFusionEnvironmentDataMaskingActivitiesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFusionEnvironmentDataMaskingActivitiesResult(
            data_masking_activity_collections=self.data_masking_activity_collections,
            filters=self.filters,
            fusion_environment_id=self.fusion_environment_id,
            id=self.id,
            state=self.state)


def get_fusion_environment_data_masking_activities(filters: Optional[Sequence[pulumi.InputType['GetFusionEnvironmentDataMaskingActivitiesFilterArgs']]] = None,
                                                   fusion_environment_id: Optional[str] = None,
                                                   state: Optional[str] = None,
                                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFusionEnvironmentDataMaskingActivitiesResult:
    """
    This data source provides the list of Fusion Environment Data Masking Activities in Oracle Cloud Infrastructure Fusion Apps service.

    Returns a list of DataMaskingActivities.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fusion_environment_data_masking_activities = oci.Functions.get_fusion_environment_data_masking_activities(fusion_environment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fusion_environment_id: unique FusionEnvironment identifier
    :param str state: A filter that returns all resources that match the specified status
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['fusionEnvironmentId'] = fusion_environment_id
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Functions/getFusionEnvironmentDataMaskingActivities:getFusionEnvironmentDataMaskingActivities', __args__, opts=opts, typ=GetFusionEnvironmentDataMaskingActivitiesResult).value

    return AwaitableGetFusionEnvironmentDataMaskingActivitiesResult(
        data_masking_activity_collections=__ret__.data_masking_activity_collections,
        filters=__ret__.filters,
        fusion_environment_id=__ret__.fusion_environment_id,
        id=__ret__.id,
        state=__ret__.state)


@_utilities.lift_output_func(get_fusion_environment_data_masking_activities)
def get_fusion_environment_data_masking_activities_output(filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetFusionEnvironmentDataMaskingActivitiesFilterArgs']]]]] = None,
                                                          fusion_environment_id: Optional[pulumi.Input[str]] = None,
                                                          state: Optional[pulumi.Input[Optional[str]]] = None,
                                                          opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetFusionEnvironmentDataMaskingActivitiesResult]:
    """
    This data source provides the list of Fusion Environment Data Masking Activities in Oracle Cloud Infrastructure Fusion Apps service.

    Returns a list of DataMaskingActivities.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fusion_environment_data_masking_activities = oci.Functions.get_fusion_environment_data_masking_activities(fusion_environment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fusion_environment_id: unique FusionEnvironment identifier
    :param str state: A filter that returns all resources that match the specified status
    """
    ...
