# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetComputeImageCapabilitySchemaResult',
    'AwaitableGetComputeImageCapabilitySchemaResult',
    'get_compute_image_capability_schema',
    'get_compute_image_capability_schema_output',
]

@pulumi.output_type
class GetComputeImageCapabilitySchemaResult:
    """
    A collection of values returned by getComputeImageCapabilitySchema.
    """
    def __init__(__self__, compartment_id=None, compute_global_image_capability_schema_id=None, compute_global_image_capability_schema_version_name=None, compute_image_capability_schema_id=None, defined_tags=None, display_name=None, freeform_tags=None, id=None, image_id=None, is_merge_enabled=None, schema_data=None, time_created=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if compute_global_image_capability_schema_id and not isinstance(compute_global_image_capability_schema_id, str):
            raise TypeError("Expected argument 'compute_global_image_capability_schema_id' to be a str")
        pulumi.set(__self__, "compute_global_image_capability_schema_id", compute_global_image_capability_schema_id)
        if compute_global_image_capability_schema_version_name and not isinstance(compute_global_image_capability_schema_version_name, str):
            raise TypeError("Expected argument 'compute_global_image_capability_schema_version_name' to be a str")
        pulumi.set(__self__, "compute_global_image_capability_schema_version_name", compute_global_image_capability_schema_version_name)
        if compute_image_capability_schema_id and not isinstance(compute_image_capability_schema_id, str):
            raise TypeError("Expected argument 'compute_image_capability_schema_id' to be a str")
        pulumi.set(__self__, "compute_image_capability_schema_id", compute_image_capability_schema_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if is_merge_enabled and not isinstance(is_merge_enabled, str):
            raise TypeError("Expected argument 'is_merge_enabled' to be a str")
        pulumi.set(__self__, "is_merge_enabled", is_merge_enabled)
        if schema_data and not isinstance(schema_data, dict):
            raise TypeError("Expected argument 'schema_data' to be a dict")
        pulumi.set(__self__, "schema_data", schema_data)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment containing the compute global image capability schema
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="computeGlobalImageCapabilitySchemaId")
    def compute_global_image_capability_schema_id(self) -> str:
        """
        The ocid of the compute global image capability schema
        """
        return pulumi.get(self, "compute_global_image_capability_schema_id")

    @property
    @pulumi.getter(name="computeGlobalImageCapabilitySchemaVersionName")
    def compute_global_image_capability_schema_version_name(self) -> str:
        """
        The name of the compute global image capability schema version
        """
        return pulumi.get(self, "compute_global_image_capability_schema_version_name")

    @property
    @pulumi.getter(name="computeImageCapabilitySchemaId")
    def compute_image_capability_schema_id(self) -> str:
        return pulumi.get(self, "compute_image_capability_schema_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The compute image capability schema [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> str:
        """
        The OCID of the image associated with this compute image capability schema
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="isMergeEnabled")
    def is_merge_enabled(self) -> Optional[str]:
        return pulumi.get(self, "is_merge_enabled")

    @property
    @pulumi.getter(name="schemaData")
    def schema_data(self) -> Mapping[str, Any]:
        """
        A mapping of each capability name to its ImageCapabilityDescriptor.
        """
        return pulumi.get(self, "schema_data")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the compute image capability schema was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).  Example: `2016-08-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")


class AwaitableGetComputeImageCapabilitySchemaResult(GetComputeImageCapabilitySchemaResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetComputeImageCapabilitySchemaResult(
            compartment_id=self.compartment_id,
            compute_global_image_capability_schema_id=self.compute_global_image_capability_schema_id,
            compute_global_image_capability_schema_version_name=self.compute_global_image_capability_schema_version_name,
            compute_image_capability_schema_id=self.compute_image_capability_schema_id,
            defined_tags=self.defined_tags,
            display_name=self.display_name,
            freeform_tags=self.freeform_tags,
            id=self.id,
            image_id=self.image_id,
            is_merge_enabled=self.is_merge_enabled,
            schema_data=self.schema_data,
            time_created=self.time_created)


def get_compute_image_capability_schema(compute_image_capability_schema_id: Optional[str] = None,
                                        is_merge_enabled: Optional[str] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetComputeImageCapabilitySchemaResult:
    """
    This data source provides details about a specific Compute Image Capability Schema resource in Oracle Cloud Infrastructure Core service.

    Gets the specified Compute Image Capability Schema

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_compute_image_capability_schema = oci.Core.get_compute_image_capability_schema(compute_image_capability_schema_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_merge_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compute_image_capability_schema_id: The id of the compute image capability schema or the image ocid
    :param str is_merge_enabled: Merge the image capability schema with the global image capability schema
    """
    __args__ = dict()
    __args__['computeImageCapabilitySchemaId'] = compute_image_capability_schema_id
    __args__['isMergeEnabled'] = is_merge_enabled
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getComputeImageCapabilitySchema:getComputeImageCapabilitySchema', __args__, opts=opts, typ=GetComputeImageCapabilitySchemaResult).value

    return AwaitableGetComputeImageCapabilitySchemaResult(
        compartment_id=__ret__.compartment_id,
        compute_global_image_capability_schema_id=__ret__.compute_global_image_capability_schema_id,
        compute_global_image_capability_schema_version_name=__ret__.compute_global_image_capability_schema_version_name,
        compute_image_capability_schema_id=__ret__.compute_image_capability_schema_id,
        defined_tags=__ret__.defined_tags,
        display_name=__ret__.display_name,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        image_id=__ret__.image_id,
        is_merge_enabled=__ret__.is_merge_enabled,
        schema_data=__ret__.schema_data,
        time_created=__ret__.time_created)


@_utilities.lift_output_func(get_compute_image_capability_schema)
def get_compute_image_capability_schema_output(compute_image_capability_schema_id: Optional[pulumi.Input[str]] = None,
                                               is_merge_enabled: Optional[pulumi.Input[Optional[str]]] = None,
                                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetComputeImageCapabilitySchemaResult]:
    """
    This data source provides details about a specific Compute Image Capability Schema resource in Oracle Cloud Infrastructure Core service.

    Gets the specified Compute Image Capability Schema

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_compute_image_capability_schema = oci.Core.get_compute_image_capability_schema(compute_image_capability_schema_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_merge_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compute_image_capability_schema_id: The id of the compute image capability schema or the image ocid
    :param str is_merge_enabled: Merge the image capability schema with the global image capability schema
    """
    ...
