# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['OperationsInsightsWarehouseDownloadWarehouseWalletArgs', 'OperationsInsightsWarehouseDownloadWarehouseWallet']

@pulumi.input_type
class OperationsInsightsWarehouseDownloadWarehouseWalletArgs:
    def __init__(__self__, *,
                 operations_insights_warehouse_id: pulumi.Input[str],
                 operations_insights_warehouse_wallet_password: pulumi.Input[str]):
        """
        The set of arguments for constructing a OperationsInsightsWarehouseDownloadWarehouseWallet resource.
        :param pulumi.Input[str] operations_insights_warehouse_id: Unique Operations Insights Warehouse identifier
        :param pulumi.Input[str] operations_insights_warehouse_wallet_password: User provided ADW wallet password for the Operations Insights Warehouse.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "operations_insights_warehouse_id", operations_insights_warehouse_id)
        pulumi.set(__self__, "operations_insights_warehouse_wallet_password", operations_insights_warehouse_wallet_password)

    @property
    @pulumi.getter(name="operationsInsightsWarehouseId")
    def operations_insights_warehouse_id(self) -> pulumi.Input[str]:
        """
        Unique Operations Insights Warehouse identifier
        """
        return pulumi.get(self, "operations_insights_warehouse_id")

    @operations_insights_warehouse_id.setter
    def operations_insights_warehouse_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "operations_insights_warehouse_id", value)

    @property
    @pulumi.getter(name="operationsInsightsWarehouseWalletPassword")
    def operations_insights_warehouse_wallet_password(self) -> pulumi.Input[str]:
        """
        User provided ADW wallet password for the Operations Insights Warehouse.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "operations_insights_warehouse_wallet_password")

    @operations_insights_warehouse_wallet_password.setter
    def operations_insights_warehouse_wallet_password(self, value: pulumi.Input[str]):
        pulumi.set(self, "operations_insights_warehouse_wallet_password", value)


@pulumi.input_type
class _OperationsInsightsWarehouseDownloadWarehouseWalletState:
    def __init__(__self__, *,
                 operations_insights_warehouse_id: Optional[pulumi.Input[str]] = None,
                 operations_insights_warehouse_wallet_password: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering OperationsInsightsWarehouseDownloadWarehouseWallet resources.
        :param pulumi.Input[str] operations_insights_warehouse_id: Unique Operations Insights Warehouse identifier
        :param pulumi.Input[str] operations_insights_warehouse_wallet_password: User provided ADW wallet password for the Operations Insights Warehouse.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        if operations_insights_warehouse_id is not None:
            pulumi.set(__self__, "operations_insights_warehouse_id", operations_insights_warehouse_id)
        if operations_insights_warehouse_wallet_password is not None:
            pulumi.set(__self__, "operations_insights_warehouse_wallet_password", operations_insights_warehouse_wallet_password)

    @property
    @pulumi.getter(name="operationsInsightsWarehouseId")
    def operations_insights_warehouse_id(self) -> Optional[pulumi.Input[str]]:
        """
        Unique Operations Insights Warehouse identifier
        """
        return pulumi.get(self, "operations_insights_warehouse_id")

    @operations_insights_warehouse_id.setter
    def operations_insights_warehouse_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "operations_insights_warehouse_id", value)

    @property
    @pulumi.getter(name="operationsInsightsWarehouseWalletPassword")
    def operations_insights_warehouse_wallet_password(self) -> Optional[pulumi.Input[str]]:
        """
        User provided ADW wallet password for the Operations Insights Warehouse.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "operations_insights_warehouse_wallet_password")

    @operations_insights_warehouse_wallet_password.setter
    def operations_insights_warehouse_wallet_password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "operations_insights_warehouse_wallet_password", value)


class OperationsInsightsWarehouseDownloadWarehouseWallet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 operations_insights_warehouse_id: Optional[pulumi.Input[str]] = None,
                 operations_insights_warehouse_wallet_password: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Operations Insights Warehouse Download Warehouse Wallet resource in Oracle Cloud Infrastructure Opsi service.

        Download the ADW wallet for Operations Insights Warehouse using which the Hub data is exposed.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_operations_insights_warehouse_download_warehouse_wallet = oci.opsi.OperationsInsightsWarehouseDownloadWarehouseWallet("testOperationsInsightsWarehouseDownloadWarehouseWallet",
            operations_insights_warehouse_id=oci_opsi_operations_insights_warehouse["test_operations_insights_warehouse"]["id"],
            operations_insights_warehouse_wallet_password=var["operations_insights_warehouse_download_warehouse_wallet_operations_insights_warehouse_wallet_password"])
        ```

        ## Import

        OperationsInsightsWarehouseDownloadWarehouseWallet can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Opsi/operationsInsightsWarehouseDownloadWarehouseWallet:OperationsInsightsWarehouseDownloadWarehouseWallet test_operations_insights_warehouse_download_warehouse_wallet "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] operations_insights_warehouse_id: Unique Operations Insights Warehouse identifier
        :param pulumi.Input[str] operations_insights_warehouse_wallet_password: User provided ADW wallet password for the Operations Insights Warehouse.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OperationsInsightsWarehouseDownloadWarehouseWalletArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Operations Insights Warehouse Download Warehouse Wallet resource in Oracle Cloud Infrastructure Opsi service.

        Download the ADW wallet for Operations Insights Warehouse using which the Hub data is exposed.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_operations_insights_warehouse_download_warehouse_wallet = oci.opsi.OperationsInsightsWarehouseDownloadWarehouseWallet("testOperationsInsightsWarehouseDownloadWarehouseWallet",
            operations_insights_warehouse_id=oci_opsi_operations_insights_warehouse["test_operations_insights_warehouse"]["id"],
            operations_insights_warehouse_wallet_password=var["operations_insights_warehouse_download_warehouse_wallet_operations_insights_warehouse_wallet_password"])
        ```

        ## Import

        OperationsInsightsWarehouseDownloadWarehouseWallet can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Opsi/operationsInsightsWarehouseDownloadWarehouseWallet:OperationsInsightsWarehouseDownloadWarehouseWallet test_operations_insights_warehouse_download_warehouse_wallet "id"
        ```

        :param str resource_name: The name of the resource.
        :param OperationsInsightsWarehouseDownloadWarehouseWalletArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OperationsInsightsWarehouseDownloadWarehouseWalletArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 operations_insights_warehouse_id: Optional[pulumi.Input[str]] = None,
                 operations_insights_warehouse_wallet_password: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OperationsInsightsWarehouseDownloadWarehouseWalletArgs.__new__(OperationsInsightsWarehouseDownloadWarehouseWalletArgs)

            if operations_insights_warehouse_id is None and not opts.urn:
                raise TypeError("Missing required property 'operations_insights_warehouse_id'")
            __props__.__dict__["operations_insights_warehouse_id"] = operations_insights_warehouse_id
            if operations_insights_warehouse_wallet_password is None and not opts.urn:
                raise TypeError("Missing required property 'operations_insights_warehouse_wallet_password'")
            __props__.__dict__["operations_insights_warehouse_wallet_password"] = None if operations_insights_warehouse_wallet_password is None else pulumi.Output.secret(operations_insights_warehouse_wallet_password)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["operationsInsightsWarehouseWalletPassword"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(OperationsInsightsWarehouseDownloadWarehouseWallet, __self__).__init__(
            'oci:Opsi/operationsInsightsWarehouseDownloadWarehouseWallet:OperationsInsightsWarehouseDownloadWarehouseWallet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            operations_insights_warehouse_id: Optional[pulumi.Input[str]] = None,
            operations_insights_warehouse_wallet_password: Optional[pulumi.Input[str]] = None) -> 'OperationsInsightsWarehouseDownloadWarehouseWallet':
        """
        Get an existing OperationsInsightsWarehouseDownloadWarehouseWallet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] operations_insights_warehouse_id: Unique Operations Insights Warehouse identifier
        :param pulumi.Input[str] operations_insights_warehouse_wallet_password: User provided ADW wallet password for the Operations Insights Warehouse.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OperationsInsightsWarehouseDownloadWarehouseWalletState.__new__(_OperationsInsightsWarehouseDownloadWarehouseWalletState)

        __props__.__dict__["operations_insights_warehouse_id"] = operations_insights_warehouse_id
        __props__.__dict__["operations_insights_warehouse_wallet_password"] = operations_insights_warehouse_wallet_password
        return OperationsInsightsWarehouseDownloadWarehouseWallet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="operationsInsightsWarehouseId")
    def operations_insights_warehouse_id(self) -> pulumi.Output[str]:
        """
        Unique Operations Insights Warehouse identifier
        """
        return pulumi.get(self, "operations_insights_warehouse_id")

    @property
    @pulumi.getter(name="operationsInsightsWarehouseWalletPassword")
    def operations_insights_warehouse_wallet_password(self) -> pulumi.Output[str]:
        """
        User provided ADW wallet password for the Operations Insights Warehouse.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "operations_insights_warehouse_wallet_password")

