# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VulnerabilityAuditArgs', 'VulnerabilityAudit']

@pulumi.input_type
class VulnerabilityAuditArgs:
    def __init__(__self__, *,
                 build_type: pulumi.Input[str],
                 knowledge_base_id: pulumi.Input[str],
                 application_dependencies: Optional[pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditApplicationDependencyArgs']]]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 configuration: Optional[pulumi.Input['VulnerabilityAuditConfigurationArgs']] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 source: Optional[pulumi.Input['VulnerabilityAuditSourceArgs']] = None):
        """
        The set of arguments for constructing a VulnerabilityAudit resource.
        :param pulumi.Input[str] build_type: The type of the build tool.
        :param pulumi.Input[str] knowledge_base_id: The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.
        :param pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditApplicationDependencyArgs']]] application_dependencies: List of Application Dependencies (without vulnerabilities).
        :param pulumi.Input[str] compartment_id: (Updatable) The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the compartment associated with the Vulnerability Audit.  If compartment identifier is not provided the compartment of the associated Knowledge Base will be used instead.
        :param pulumi.Input['VulnerabilityAuditConfigurationArgs'] configuration: Configuration for a Vulnerability Audit. A vulnerable Application Dependency is ignored if its name does match any of the items in `exclusions`, or all of the associated Vulnerabilies have a CVSS v2 score below `maxPermissibleCvssV2Score` and a CVSS v3 score below `maxPermissibleCvssV3Score`. type: object
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] display_name: (Updatable) The name of the Vulnerability Audit.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input['VulnerabilityAuditSourceArgs'] source: Vulnerability Audit source.
        """
        pulumi.set(__self__, "build_type", build_type)
        pulumi.set(__self__, "knowledge_base_id", knowledge_base_id)
        if application_dependencies is not None:
            pulumi.set(__self__, "application_dependencies", application_dependencies)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if configuration is not None:
            pulumi.set(__self__, "configuration", configuration)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if source is not None:
            pulumi.set(__self__, "source", source)

    @property
    @pulumi.getter(name="buildType")
    def build_type(self) -> pulumi.Input[str]:
        """
        The type of the build tool.
        """
        return pulumi.get(self, "build_type")

    @build_type.setter
    def build_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "build_type", value)

    @property
    @pulumi.getter(name="knowledgeBaseId")
    def knowledge_base_id(self) -> pulumi.Input[str]:
        """
        The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.
        """
        return pulumi.get(self, "knowledge_base_id")

    @knowledge_base_id.setter
    def knowledge_base_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "knowledge_base_id", value)

    @property
    @pulumi.getter(name="applicationDependencies")
    def application_dependencies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditApplicationDependencyArgs']]]]:
        """
        List of Application Dependencies (without vulnerabilities).
        """
        return pulumi.get(self, "application_dependencies")

    @application_dependencies.setter
    def application_dependencies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditApplicationDependencyArgs']]]]):
        pulumi.set(self, "application_dependencies", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the compartment associated with the Vulnerability Audit.  If compartment identifier is not provided the compartment of the associated Knowledge Base will be used instead.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter
    def configuration(self) -> Optional[pulumi.Input['VulnerabilityAuditConfigurationArgs']]:
        """
        Configuration for a Vulnerability Audit. A vulnerable Application Dependency is ignored if its name does match any of the items in `exclusions`, or all of the associated Vulnerabilies have a CVSS v2 score below `maxPermissibleCvssV2Score` and a CVSS v3 score below `maxPermissibleCvssV3Score`. type: object
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: Optional[pulumi.Input['VulnerabilityAuditConfigurationArgs']]):
        pulumi.set(self, "configuration", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The name of the Vulnerability Audit.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input['VulnerabilityAuditSourceArgs']]:
        """
        Vulnerability Audit source.
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input['VulnerabilityAuditSourceArgs']]):
        pulumi.set(self, "source", value)


@pulumi.input_type
class _VulnerabilityAuditState:
    def __init__(__self__, *,
                 application_dependencies: Optional[pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditApplicationDependencyArgs']]]] = None,
                 build_type: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 configuration: Optional[pulumi.Input['VulnerabilityAuditConfigurationArgs']] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 is_success: Optional[pulumi.Input[bool]] = None,
                 knowledge_base_id: Optional[pulumi.Input[str]] = None,
                 max_observed_cvss_v2score: Optional[pulumi.Input[float]] = None,
                 max_observed_cvss_v2score_with_ignored: Optional[pulumi.Input[float]] = None,
                 max_observed_cvss_v3score: Optional[pulumi.Input[float]] = None,
                 max_observed_cvss_v3score_with_ignored: Optional[pulumi.Input[float]] = None,
                 source: Optional[pulumi.Input['VulnerabilityAuditSourceArgs']] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None,
                 vulnerabilities: Optional[pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditVulnerabilityArgs']]]] = None,
                 vulnerable_artifacts_count: Optional[pulumi.Input[int]] = None,
                 vulnerable_artifacts_count_with_ignored: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering VulnerabilityAudit resources.
        :param pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditApplicationDependencyArgs']]] application_dependencies: List of Application Dependencies (without vulnerabilities).
        :param pulumi.Input[str] build_type: The type of the build tool.
        :param pulumi.Input[str] compartment_id: (Updatable) The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the compartment associated with the Vulnerability Audit.  If compartment identifier is not provided the compartment of the associated Knowledge Base will be used instead.
        :param pulumi.Input['VulnerabilityAuditConfigurationArgs'] configuration: Configuration for a Vulnerability Audit. A vulnerable Application Dependency is ignored if its name does match any of the items in `exclusions`, or all of the associated Vulnerabilies have a CVSS v2 score below `maxPermissibleCvssV2Score` and a CVSS v3 score below `maxPermissibleCvssV3Score`. type: object
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] display_name: (Updatable) The name of the Vulnerability Audit.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[bool] is_success: Indicates if an audit succeeded according to the configuration. The value is `null` if the audit is in the `CREATING` state.
        :param pulumi.Input[str] knowledge_base_id: The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.
        :param pulumi.Input[float] max_observed_cvss_v2score: Maximum Common Vulnerability Scoring System Version 2 score observed for non-ignored vulnerable Application Dependencies.
        :param pulumi.Input[float] max_observed_cvss_v2score_with_ignored: Maximum Common Vulnerability Scoring System Version 2 score observed for vulnerable Application Dependencies including ignored ones.
        :param pulumi.Input[float] max_observed_cvss_v3score: Maximum Common Vulnerability Scoring System Version 3 score observed for non-ignored vulnerable Application Dependencies.
        :param pulumi.Input[float] max_observed_cvss_v3score_with_ignored: Maximum Common Vulnerability Scoring System Version 3 score observed for vulnerable Application Dependencies including ignored ones.
        :param pulumi.Input['VulnerabilityAuditSourceArgs'] source: Vulnerability Audit source.
        :param pulumi.Input[str] state: The current lifecycle state of the Vulnerability Audit.
        :param pulumi.Input[Mapping[str, Any]] system_tags: Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param pulumi.Input[str] time_created: The creation date and time of the Vulnerability Audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param pulumi.Input[str] time_updated: The update date and time of the Vulnerability Audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditVulnerabilityArgs']]] vulnerabilities: List of vulnerabilities found in the Vulnerability Audit.
        :param pulumi.Input[int] vulnerable_artifacts_count: Count of non-ignored vulnerable Application Dependencies.
        :param pulumi.Input[int] vulnerable_artifacts_count_with_ignored: Count of all vulnerable Application Dependencies.
        """
        if application_dependencies is not None:
            pulumi.set(__self__, "application_dependencies", application_dependencies)
        if build_type is not None:
            pulumi.set(__self__, "build_type", build_type)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if configuration is not None:
            pulumi.set(__self__, "configuration", configuration)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if is_success is not None:
            pulumi.set(__self__, "is_success", is_success)
        if knowledge_base_id is not None:
            pulumi.set(__self__, "knowledge_base_id", knowledge_base_id)
        if max_observed_cvss_v2score is not None:
            pulumi.set(__self__, "max_observed_cvss_v2score", max_observed_cvss_v2score)
        if max_observed_cvss_v2score_with_ignored is not None:
            pulumi.set(__self__, "max_observed_cvss_v2score_with_ignored", max_observed_cvss_v2score_with_ignored)
        if max_observed_cvss_v3score is not None:
            pulumi.set(__self__, "max_observed_cvss_v3score", max_observed_cvss_v3score)
        if max_observed_cvss_v3score_with_ignored is not None:
            pulumi.set(__self__, "max_observed_cvss_v3score_with_ignored", max_observed_cvss_v3score_with_ignored)
        if source is not None:
            pulumi.set(__self__, "source", source)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if system_tags is not None:
            pulumi.set(__self__, "system_tags", system_tags)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)
        if vulnerabilities is not None:
            pulumi.set(__self__, "vulnerabilities", vulnerabilities)
        if vulnerable_artifacts_count is not None:
            pulumi.set(__self__, "vulnerable_artifacts_count", vulnerable_artifacts_count)
        if vulnerable_artifacts_count_with_ignored is not None:
            pulumi.set(__self__, "vulnerable_artifacts_count_with_ignored", vulnerable_artifacts_count_with_ignored)

    @property
    @pulumi.getter(name="applicationDependencies")
    def application_dependencies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditApplicationDependencyArgs']]]]:
        """
        List of Application Dependencies (without vulnerabilities).
        """
        return pulumi.get(self, "application_dependencies")

    @application_dependencies.setter
    def application_dependencies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditApplicationDependencyArgs']]]]):
        pulumi.set(self, "application_dependencies", value)

    @property
    @pulumi.getter(name="buildType")
    def build_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the build tool.
        """
        return pulumi.get(self, "build_type")

    @build_type.setter
    def build_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "build_type", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the compartment associated with the Vulnerability Audit.  If compartment identifier is not provided the compartment of the associated Knowledge Base will be used instead.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter
    def configuration(self) -> Optional[pulumi.Input['VulnerabilityAuditConfigurationArgs']]:
        """
        Configuration for a Vulnerability Audit. A vulnerable Application Dependency is ignored if its name does match any of the items in `exclusions`, or all of the associated Vulnerabilies have a CVSS v2 score below `maxPermissibleCvssV2Score` and a CVSS v3 score below `maxPermissibleCvssV3Score`. type: object
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: Optional[pulumi.Input['VulnerabilityAuditConfigurationArgs']]):
        pulumi.set(self, "configuration", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The name of the Vulnerability Audit.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="isSuccess")
    def is_success(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if an audit succeeded according to the configuration. The value is `null` if the audit is in the `CREATING` state.
        """
        return pulumi.get(self, "is_success")

    @is_success.setter
    def is_success(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_success", value)

    @property
    @pulumi.getter(name="knowledgeBaseId")
    def knowledge_base_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.
        """
        return pulumi.get(self, "knowledge_base_id")

    @knowledge_base_id.setter
    def knowledge_base_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "knowledge_base_id", value)

    @property
    @pulumi.getter(name="maxObservedCvssV2score")
    def max_observed_cvss_v2score(self) -> Optional[pulumi.Input[float]]:
        """
        Maximum Common Vulnerability Scoring System Version 2 score observed for non-ignored vulnerable Application Dependencies.
        """
        return pulumi.get(self, "max_observed_cvss_v2score")

    @max_observed_cvss_v2score.setter
    def max_observed_cvss_v2score(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "max_observed_cvss_v2score", value)

    @property
    @pulumi.getter(name="maxObservedCvssV2scoreWithIgnored")
    def max_observed_cvss_v2score_with_ignored(self) -> Optional[pulumi.Input[float]]:
        """
        Maximum Common Vulnerability Scoring System Version 2 score observed for vulnerable Application Dependencies including ignored ones.
        """
        return pulumi.get(self, "max_observed_cvss_v2score_with_ignored")

    @max_observed_cvss_v2score_with_ignored.setter
    def max_observed_cvss_v2score_with_ignored(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "max_observed_cvss_v2score_with_ignored", value)

    @property
    @pulumi.getter(name="maxObservedCvssV3score")
    def max_observed_cvss_v3score(self) -> Optional[pulumi.Input[float]]:
        """
        Maximum Common Vulnerability Scoring System Version 3 score observed for non-ignored vulnerable Application Dependencies.
        """
        return pulumi.get(self, "max_observed_cvss_v3score")

    @max_observed_cvss_v3score.setter
    def max_observed_cvss_v3score(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "max_observed_cvss_v3score", value)

    @property
    @pulumi.getter(name="maxObservedCvssV3scoreWithIgnored")
    def max_observed_cvss_v3score_with_ignored(self) -> Optional[pulumi.Input[float]]:
        """
        Maximum Common Vulnerability Scoring System Version 3 score observed for vulnerable Application Dependencies including ignored ones.
        """
        return pulumi.get(self, "max_observed_cvss_v3score_with_ignored")

    @max_observed_cvss_v3score_with_ignored.setter
    def max_observed_cvss_v3score_with_ignored(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "max_observed_cvss_v3score_with_ignored", value)

    @property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input['VulnerabilityAuditSourceArgs']]:
        """
        Vulnerability Audit source.
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input['VulnerabilityAuditSourceArgs']]):
        pulumi.set(self, "source", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current lifecycle state of the Vulnerability Audit.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @system_tags.setter
    def system_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "system_tags", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The creation date and time of the Vulnerability Audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The update date and time of the Vulnerability Audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)

    @property
    @pulumi.getter
    def vulnerabilities(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditVulnerabilityArgs']]]]:
        """
        List of vulnerabilities found in the Vulnerability Audit.
        """
        return pulumi.get(self, "vulnerabilities")

    @vulnerabilities.setter
    def vulnerabilities(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VulnerabilityAuditVulnerabilityArgs']]]]):
        pulumi.set(self, "vulnerabilities", value)

    @property
    @pulumi.getter(name="vulnerableArtifactsCount")
    def vulnerable_artifacts_count(self) -> Optional[pulumi.Input[int]]:
        """
        Count of non-ignored vulnerable Application Dependencies.
        """
        return pulumi.get(self, "vulnerable_artifacts_count")

    @vulnerable_artifacts_count.setter
    def vulnerable_artifacts_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "vulnerable_artifacts_count", value)

    @property
    @pulumi.getter(name="vulnerableArtifactsCountWithIgnored")
    def vulnerable_artifacts_count_with_ignored(self) -> Optional[pulumi.Input[int]]:
        """
        Count of all vulnerable Application Dependencies.
        """
        return pulumi.get(self, "vulnerable_artifacts_count_with_ignored")

    @vulnerable_artifacts_count_with_ignored.setter
    def vulnerable_artifacts_count_with_ignored(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "vulnerable_artifacts_count_with_ignored", value)


class VulnerabilityAudit(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_dependencies: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VulnerabilityAuditApplicationDependencyArgs']]]]] = None,
                 build_type: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 configuration: Optional[pulumi.Input[pulumi.InputType['VulnerabilityAuditConfigurationArgs']]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 knowledge_base_id: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[pulumi.InputType['VulnerabilityAuditSourceArgs']]] = None,
                 __props__=None):
        """
        This resource provides the Vulnerability Audit resource in Oracle Cloud Infrastructure Adm service.

        Creates a new Vulnerability Audit by providing a tree of Application Dependencies.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_vulnerability_audit = oci.adm.VulnerabilityAudit("testVulnerabilityAudit",
            build_type=var["vulnerability_audit_build_type"],
            knowledge_base_id=oci_adm_knowledge_base["test_knowledge_base"]["id"],
            application_dependencies=[oci.adm.VulnerabilityAuditApplicationDependencyArgs(
                gav=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                node_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                application_dependency_node_ids=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )],
            compartment_id=var["compartment_id"],
            configuration=oci.adm.VulnerabilityAuditConfigurationArgs(
                exclusions=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_permissible_cvss_v2score=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_permissible_cvss_v3score=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            display_name=var["vulnerability_audit_display_name"],
            freeform_tags={
                "bar-key": "value",
            },
            source=oci.adm.VulnerabilityAuditSourceArgs(
                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                oci_resource_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ))
        ```

        ## Import

        VulnerabilityAudits can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Adm/vulnerabilityAudit:VulnerabilityAudit test_vulnerability_audit "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VulnerabilityAuditApplicationDependencyArgs']]]] application_dependencies: List of Application Dependencies (without vulnerabilities).
        :param pulumi.Input[str] build_type: The type of the build tool.
        :param pulumi.Input[str] compartment_id: (Updatable) The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the compartment associated with the Vulnerability Audit.  If compartment identifier is not provided the compartment of the associated Knowledge Base will be used instead.
        :param pulumi.Input[pulumi.InputType['VulnerabilityAuditConfigurationArgs']] configuration: Configuration for a Vulnerability Audit. A vulnerable Application Dependency is ignored if its name does match any of the items in `exclusions`, or all of the associated Vulnerabilies have a CVSS v2 score below `maxPermissibleCvssV2Score` and a CVSS v3 score below `maxPermissibleCvssV3Score`. type: object
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] display_name: (Updatable) The name of the Vulnerability Audit.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[str] knowledge_base_id: The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.
        :param pulumi.Input[pulumi.InputType['VulnerabilityAuditSourceArgs']] source: Vulnerability Audit source.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VulnerabilityAuditArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Vulnerability Audit resource in Oracle Cloud Infrastructure Adm service.

        Creates a new Vulnerability Audit by providing a tree of Application Dependencies.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_vulnerability_audit = oci.adm.VulnerabilityAudit("testVulnerabilityAudit",
            build_type=var["vulnerability_audit_build_type"],
            knowledge_base_id=oci_adm_knowledge_base["test_knowledge_base"]["id"],
            application_dependencies=[oci.adm.VulnerabilityAuditApplicationDependencyArgs(
                gav=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                node_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                application_dependency_node_ids=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )],
            compartment_id=var["compartment_id"],
            configuration=oci.adm.VulnerabilityAuditConfigurationArgs(
                exclusions=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_permissible_cvss_v2score=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                max_permissible_cvss_v3score=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            defined_tags={
                "foo-namespace.bar-key": "value",
            },
            display_name=var["vulnerability_audit_display_name"],
            freeform_tags={
                "bar-key": "value",
            },
            source=oci.adm.VulnerabilityAuditSourceArgs(
                type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                oci_resource_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ))
        ```

        ## Import

        VulnerabilityAudits can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Adm/vulnerabilityAudit:VulnerabilityAudit test_vulnerability_audit "id"
        ```

        :param str resource_name: The name of the resource.
        :param VulnerabilityAuditArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VulnerabilityAuditArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_dependencies: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VulnerabilityAuditApplicationDependencyArgs']]]]] = None,
                 build_type: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 configuration: Optional[pulumi.Input[pulumi.InputType['VulnerabilityAuditConfigurationArgs']]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 knowledge_base_id: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[pulumi.InputType['VulnerabilityAuditSourceArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VulnerabilityAuditArgs.__new__(VulnerabilityAuditArgs)

            __props__.__dict__["application_dependencies"] = application_dependencies
            if build_type is None and not opts.urn:
                raise TypeError("Missing required property 'build_type'")
            __props__.__dict__["build_type"] = build_type
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["configuration"] = configuration
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["freeform_tags"] = freeform_tags
            if knowledge_base_id is None and not opts.urn:
                raise TypeError("Missing required property 'knowledge_base_id'")
            __props__.__dict__["knowledge_base_id"] = knowledge_base_id
            __props__.__dict__["source"] = source
            __props__.__dict__["is_success"] = None
            __props__.__dict__["max_observed_cvss_v2score"] = None
            __props__.__dict__["max_observed_cvss_v2score_with_ignored"] = None
            __props__.__dict__["max_observed_cvss_v3score"] = None
            __props__.__dict__["max_observed_cvss_v3score_with_ignored"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["system_tags"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_updated"] = None
            __props__.__dict__["vulnerabilities"] = None
            __props__.__dict__["vulnerable_artifacts_count"] = None
            __props__.__dict__["vulnerable_artifacts_count_with_ignored"] = None
        super(VulnerabilityAudit, __self__).__init__(
            'oci:Adm/vulnerabilityAudit:VulnerabilityAudit',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_dependencies: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VulnerabilityAuditApplicationDependencyArgs']]]]] = None,
            build_type: Optional[pulumi.Input[str]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            configuration: Optional[pulumi.Input[pulumi.InputType['VulnerabilityAuditConfigurationArgs']]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            is_success: Optional[pulumi.Input[bool]] = None,
            knowledge_base_id: Optional[pulumi.Input[str]] = None,
            max_observed_cvss_v2score: Optional[pulumi.Input[float]] = None,
            max_observed_cvss_v2score_with_ignored: Optional[pulumi.Input[float]] = None,
            max_observed_cvss_v3score: Optional[pulumi.Input[float]] = None,
            max_observed_cvss_v3score_with_ignored: Optional[pulumi.Input[float]] = None,
            source: Optional[pulumi.Input[pulumi.InputType['VulnerabilityAuditSourceArgs']]] = None,
            state: Optional[pulumi.Input[str]] = None,
            system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None,
            vulnerabilities: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VulnerabilityAuditVulnerabilityArgs']]]]] = None,
            vulnerable_artifacts_count: Optional[pulumi.Input[int]] = None,
            vulnerable_artifacts_count_with_ignored: Optional[pulumi.Input[int]] = None) -> 'VulnerabilityAudit':
        """
        Get an existing VulnerabilityAudit resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VulnerabilityAuditApplicationDependencyArgs']]]] application_dependencies: List of Application Dependencies (without vulnerabilities).
        :param pulumi.Input[str] build_type: The type of the build tool.
        :param pulumi.Input[str] compartment_id: (Updatable) The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the compartment associated with the Vulnerability Audit.  If compartment identifier is not provided the compartment of the associated Knowledge Base will be used instead.
        :param pulumi.Input[pulumi.InputType['VulnerabilityAuditConfigurationArgs']] configuration: Configuration for a Vulnerability Audit. A vulnerable Application Dependency is ignored if its name does match any of the items in `exclusions`, or all of the associated Vulnerabilies have a CVSS v2 score below `maxPermissibleCvssV2Score` and a CVSS v3 score below `maxPermissibleCvssV3Score`. type: object
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param pulumi.Input[str] display_name: (Updatable) The name of the Vulnerability Audit.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param pulumi.Input[bool] is_success: Indicates if an audit succeeded according to the configuration. The value is `null` if the audit is in the `CREATING` state.
        :param pulumi.Input[str] knowledge_base_id: The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.
        :param pulumi.Input[float] max_observed_cvss_v2score: Maximum Common Vulnerability Scoring System Version 2 score observed for non-ignored vulnerable Application Dependencies.
        :param pulumi.Input[float] max_observed_cvss_v2score_with_ignored: Maximum Common Vulnerability Scoring System Version 2 score observed for vulnerable Application Dependencies including ignored ones.
        :param pulumi.Input[float] max_observed_cvss_v3score: Maximum Common Vulnerability Scoring System Version 3 score observed for non-ignored vulnerable Application Dependencies.
        :param pulumi.Input[float] max_observed_cvss_v3score_with_ignored: Maximum Common Vulnerability Scoring System Version 3 score observed for vulnerable Application Dependencies including ignored ones.
        :param pulumi.Input[pulumi.InputType['VulnerabilityAuditSourceArgs']] source: Vulnerability Audit source.
        :param pulumi.Input[str] state: The current lifecycle state of the Vulnerability Audit.
        :param pulumi.Input[Mapping[str, Any]] system_tags: Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param pulumi.Input[str] time_created: The creation date and time of the Vulnerability Audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param pulumi.Input[str] time_updated: The update date and time of the Vulnerability Audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['VulnerabilityAuditVulnerabilityArgs']]]] vulnerabilities: List of vulnerabilities found in the Vulnerability Audit.
        :param pulumi.Input[int] vulnerable_artifacts_count: Count of non-ignored vulnerable Application Dependencies.
        :param pulumi.Input[int] vulnerable_artifacts_count_with_ignored: Count of all vulnerable Application Dependencies.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VulnerabilityAuditState.__new__(_VulnerabilityAuditState)

        __props__.__dict__["application_dependencies"] = application_dependencies
        __props__.__dict__["build_type"] = build_type
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["configuration"] = configuration
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["is_success"] = is_success
        __props__.__dict__["knowledge_base_id"] = knowledge_base_id
        __props__.__dict__["max_observed_cvss_v2score"] = max_observed_cvss_v2score
        __props__.__dict__["max_observed_cvss_v2score_with_ignored"] = max_observed_cvss_v2score_with_ignored
        __props__.__dict__["max_observed_cvss_v3score"] = max_observed_cvss_v3score
        __props__.__dict__["max_observed_cvss_v3score_with_ignored"] = max_observed_cvss_v3score_with_ignored
        __props__.__dict__["source"] = source
        __props__.__dict__["state"] = state
        __props__.__dict__["system_tags"] = system_tags
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_updated"] = time_updated
        __props__.__dict__["vulnerabilities"] = vulnerabilities
        __props__.__dict__["vulnerable_artifacts_count"] = vulnerable_artifacts_count
        __props__.__dict__["vulnerable_artifacts_count_with_ignored"] = vulnerable_artifacts_count_with_ignored
        return VulnerabilityAudit(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="applicationDependencies")
    def application_dependencies(self) -> pulumi.Output[Sequence['outputs.VulnerabilityAuditApplicationDependency']]:
        """
        List of Application Dependencies (without vulnerabilities).
        """
        return pulumi.get(self, "application_dependencies")

    @property
    @pulumi.getter(name="buildType")
    def build_type(self) -> pulumi.Output[str]:
        """
        The type of the build tool.
        """
        return pulumi.get(self, "build_type")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the compartment associated with the Vulnerability Audit.  If compartment identifier is not provided the compartment of the associated Knowledge Base will be used instead.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def configuration(self) -> pulumi.Output['outputs.VulnerabilityAuditConfiguration']:
        """
        Configuration for a Vulnerability Audit. A vulnerable Application Dependency is ignored if its name does match any of the items in `exclusions`, or all of the associated Vulnerabilies have a CVSS v2 score below `maxPermissibleCvssV2Score` and a CVSS v3 score below `maxPermissibleCvssV3Score`. type: object
        """
        return pulumi.get(self, "configuration")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) The name of the Vulnerability Audit.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="isSuccess")
    def is_success(self) -> pulumi.Output[bool]:
        """
        Indicates if an audit succeeded according to the configuration. The value is `null` if the audit is in the `CREATING` state.
        """
        return pulumi.get(self, "is_success")

    @property
    @pulumi.getter(name="knowledgeBaseId")
    def knowledge_base_id(self) -> pulumi.Output[str]:
        """
        The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the Knowledge Base.
        """
        return pulumi.get(self, "knowledge_base_id")

    @property
    @pulumi.getter(name="maxObservedCvssV2score")
    def max_observed_cvss_v2score(self) -> pulumi.Output[float]:
        """
        Maximum Common Vulnerability Scoring System Version 2 score observed for non-ignored vulnerable Application Dependencies.
        """
        return pulumi.get(self, "max_observed_cvss_v2score")

    @property
    @pulumi.getter(name="maxObservedCvssV2scoreWithIgnored")
    def max_observed_cvss_v2score_with_ignored(self) -> pulumi.Output[float]:
        """
        Maximum Common Vulnerability Scoring System Version 2 score observed for vulnerable Application Dependencies including ignored ones.
        """
        return pulumi.get(self, "max_observed_cvss_v2score_with_ignored")

    @property
    @pulumi.getter(name="maxObservedCvssV3score")
    def max_observed_cvss_v3score(self) -> pulumi.Output[float]:
        """
        Maximum Common Vulnerability Scoring System Version 3 score observed for non-ignored vulnerable Application Dependencies.
        """
        return pulumi.get(self, "max_observed_cvss_v3score")

    @property
    @pulumi.getter(name="maxObservedCvssV3scoreWithIgnored")
    def max_observed_cvss_v3score_with_ignored(self) -> pulumi.Output[float]:
        """
        Maximum Common Vulnerability Scoring System Version 3 score observed for vulnerable Application Dependencies including ignored ones.
        """
        return pulumi.get(self, "max_observed_cvss_v3score_with_ignored")

    @property
    @pulumi.getter
    def source(self) -> pulumi.Output['outputs.VulnerabilityAuditSource']:
        """
        Vulnerability Audit source.
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current lifecycle state of the Vulnerability Audit.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The creation date and time of the Vulnerability Audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The update date and time of the Vulnerability Audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter
    def vulnerabilities(self) -> pulumi.Output[Sequence['outputs.VulnerabilityAuditVulnerability']]:
        """
        List of vulnerabilities found in the Vulnerability Audit.
        """
        return pulumi.get(self, "vulnerabilities")

    @property
    @pulumi.getter(name="vulnerableArtifactsCount")
    def vulnerable_artifacts_count(self) -> pulumi.Output[int]:
        """
        Count of non-ignored vulnerable Application Dependencies.
        """
        return pulumi.get(self, "vulnerable_artifacts_count")

    @property
    @pulumi.getter(name="vulnerableArtifactsCountWithIgnored")
    def vulnerable_artifacts_count_with_ignored(self) -> pulumi.Output[int]:
        """
        Count of all vulnerable Application Dependencies.
        """
        return pulumi.get(self, "vulnerable_artifacts_count_with_ignored")

