# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAppAccelerationPoliciesResult',
    'AwaitableGetAppAccelerationPoliciesResult',
    'get_app_acceleration_policies',
    'get_app_acceleration_policies_output',
]

@pulumi.output_type
class GetAppAccelerationPoliciesResult:
    """
    A collection of values returned by getAppAccelerationPolicies.
    """
    def __init__(__self__, compartment_id=None, display_name=None, filters=None, id=None, states=None, web_app_acceleration_policy_collections=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if states and not isinstance(states, list):
            raise TypeError("Expected argument 'states' to be a list")
        pulumi.set(__self__, "states", states)
        if web_app_acceleration_policy_collections and not isinstance(web_app_acceleration_policy_collections, list):
            raise TypeError("Expected argument 'web_app_acceleration_policy_collections' to be a list")
        pulumi.set(__self__, "web_app_acceleration_policy_collections", web_app_acceleration_policy_collections)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        WebAppAccelerationPolicy display name, can be renamed.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAppAccelerationPoliciesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the WebAppAccelerationPolicy.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def states(self) -> Optional[Sequence[str]]:
        """
        The current state of the WebAppAccelerationPolicy.
        """
        return pulumi.get(self, "states")

    @property
    @pulumi.getter(name="webAppAccelerationPolicyCollections")
    def web_app_acceleration_policy_collections(self) -> Sequence['outputs.GetAppAccelerationPoliciesWebAppAccelerationPolicyCollectionResult']:
        """
        The list of web_app_acceleration_policy_collection.
        """
        return pulumi.get(self, "web_app_acceleration_policy_collections")


class AwaitableGetAppAccelerationPoliciesResult(GetAppAccelerationPoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppAccelerationPoliciesResult(
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            states=self.states,
            web_app_acceleration_policy_collections=self.web_app_acceleration_policy_collections)


def get_app_acceleration_policies(compartment_id: Optional[str] = None,
                                  display_name: Optional[str] = None,
                                  filters: Optional[Sequence[pulumi.InputType['GetAppAccelerationPoliciesFilterArgs']]] = None,
                                  id: Optional[str] = None,
                                  states: Optional[Sequence[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAppAccelerationPoliciesResult:
    """
    This data source provides the list of Web App Acceleration Policies in Oracle Cloud Infrastructure Waa service.

    Gets a list of all WebAppAccelerationPolicies in a compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_web_app_acceleration_policies = oci.Waa.get_app_acceleration_policies(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        states=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which to list resources.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str id: A filter to return only the WebAppAccelerationPolicy with the given [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param Sequence[str] states: A filter to return only resources that match the given lifecycleState.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['id'] = id
    __args__['states'] = states
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Waa/getAppAccelerationPolicies:getAppAccelerationPolicies', __args__, opts=opts, typ=GetAppAccelerationPoliciesResult).value

    return AwaitableGetAppAccelerationPoliciesResult(
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        states=__ret__.states,
        web_app_acceleration_policy_collections=__ret__.web_app_acceleration_policy_collections)


@_utilities.lift_output_func(get_app_acceleration_policies)
def get_app_acceleration_policies_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                         display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                         filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAppAccelerationPoliciesFilterArgs']]]]] = None,
                                         id: Optional[pulumi.Input[Optional[str]]] = None,
                                         states: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAppAccelerationPoliciesResult]:
    """
    This data source provides the list of Web App Acceleration Policies in Oracle Cloud Infrastructure Waa service.

    Gets a list of all WebAppAccelerationPolicies in a compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_web_app_acceleration_policies = oci.Waa.get_app_acceleration_policies(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        states=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which to list resources.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str id: A filter to return only the WebAppAccelerationPolicy with the given [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param Sequence[str] states: A filter to return only resources that match the given lifecycleState.
    """
    ...
