# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetProxyDetailResult',
    'AwaitableGetProxyDetailResult',
    'get_proxy_detail',
]

@pulumi.output_type
class GetProxyDetailResult:
    """
    A collection of values returned by getProxyDetail.
    """
    def __init__(__self__, id=None, proxy_image=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if proxy_image and not isinstance(proxy_image, str):
            raise TypeError("Expected argument 'proxy_image' to be a str")
        pulumi.set(__self__, "proxy_image", proxy_image)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="proxyImage")
    def proxy_image(self) -> str:
        """
        Proxy container image version to be deployed.
        """
        return pulumi.get(self, "proxy_image")


class AwaitableGetProxyDetailResult(GetProxyDetailResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProxyDetailResult(
            id=self.id,
            proxy_image=self.proxy_image)


def get_proxy_detail(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProxyDetailResult:
    """
    This data source provides details about a specific Proxy Detail resource in Oracle Cloud Infrastructure Service Mesh service.

    Returns the attributes of the Proxy such as proxy image version.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_proxy_detail = oci.ServiceMesh.get_proxy_detail()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:ServiceMesh/getProxyDetail:getProxyDetail', __args__, opts=opts, typ=GetProxyDetailResult).value

    return AwaitableGetProxyDetailResult(
        id=__ret__.id,
        proxy_image=__ret__.proxy_image)
