# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstanceConfigurationArgs', 'InstanceConfiguration']

@pulumi.input_type
class InstanceConfigurationArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 instance_details: Optional[pulumi.Input['InstanceConfigurationInstanceDetailsArgs']] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a InstanceConfiguration resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment containing the instance. Instances created from instance configurations are placed in the same compartment as the instance that was used to create the instance configuration.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] instance_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance to use to create the instance configuration.
        :param pulumi.Input[str] source: The source of the instance configuration. An instance configuration defines the settings to use when creating Compute instances, including details such as the base image, shape, and metadata. You can also specify the associated resources for the instance, such as block volume attachments and network configuration.
               
               When you create an instance configuration using an existing instance as a template, the instance configuration does not include any information from the source instance's boot volume, such as installed applications, binaries, and files on the instance. It also does not include the contents of any block volumes that are attached to the instance.
               
               To create an instance configuration that includes the custom setup from an instance's boot volume, you must first create a custom image from the instance (see [CreateImage](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Image/CreateImage)). Then, use the custom image to launch a new instance (see [LaunchInstance](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstance)). Finally, create the instance configuration based on the instance that you created from the custom image.
               
               To include block volume contents with an instance configuration, first create a backup of the attached block volumes (see [CreateVolumeBackup](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/VolumeBackup/CreateVolumeBackup)). Then, create the instance configuration by specifying the list of settings, using [InstanceConfigurationVolumeSourceFromVolumeBackupDetails](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/datatypes/InstanceConfigurationVolumeSourceFromVolumeBackupDetails) to include the block volume backups in the list of settings.
               
               The following values are supported:
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if instance_details is not None:
            pulumi.set(__self__, "instance_details", instance_details)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if source is not None:
            pulumi.set(__self__, "source", source)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        The OCID of the compartment containing the instance. Instances created from instance configurations are placed in the same compartment as the instance that was used to create the instance configuration.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="instanceDetails")
    def instance_details(self) -> Optional[pulumi.Input['InstanceConfigurationInstanceDetailsArgs']]:
        return pulumi.get(self, "instance_details")

    @instance_details.setter
    def instance_details(self, value: Optional[pulumi.Input['InstanceConfigurationInstanceDetailsArgs']]):
        pulumi.set(self, "instance_details", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance to use to create the instance configuration.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input[str]]:
        """
        The source of the instance configuration. An instance configuration defines the settings to use when creating Compute instances, including details such as the base image, shape, and metadata. You can also specify the associated resources for the instance, such as block volume attachments and network configuration.

        When you create an instance configuration using an existing instance as a template, the instance configuration does not include any information from the source instance's boot volume, such as installed applications, binaries, and files on the instance. It also does not include the contents of any block volumes that are attached to the instance.

        To create an instance configuration that includes the custom setup from an instance's boot volume, you must first create a custom image from the instance (see [CreateImage](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Image/CreateImage)). Then, use the custom image to launch a new instance (see [LaunchInstance](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstance)). Finally, create the instance configuration based on the instance that you created from the custom image.

        To include block volume contents with an instance configuration, first create a backup of the attached block volumes (see [CreateVolumeBackup](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/VolumeBackup/CreateVolumeBackup)). Then, create the instance configuration by specifying the list of settings, using [InstanceConfigurationVolumeSourceFromVolumeBackupDetails](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/datatypes/InstanceConfigurationVolumeSourceFromVolumeBackupDetails) to include the block volume backups in the list of settings.

        The following values are supported:
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source", value)


@pulumi.input_type
class _InstanceConfigurationState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 deferred_fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 instance_details: Optional[pulumi.Input['InstanceConfigurationInstanceDetailsArgs']] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[str]] = None,
                 time_created: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering InstanceConfiguration resources.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment containing the instance. Instances created from instance configurations are placed in the same compartment as the instance that was used to create the instance configuration.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] deferred_fields: Parameters that were not specified when the instance configuration was created, but that are required to launch an instance from the instance configuration. See the [LaunchInstanceConfiguration](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstanceConfiguration) operation.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] instance_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance to use to create the instance configuration.
        :param pulumi.Input[str] source: The source of the instance configuration. An instance configuration defines the settings to use when creating Compute instances, including details such as the base image, shape, and metadata. You can also specify the associated resources for the instance, such as block volume attachments and network configuration.
               
               When you create an instance configuration using an existing instance as a template, the instance configuration does not include any information from the source instance's boot volume, such as installed applications, binaries, and files on the instance. It also does not include the contents of any block volumes that are attached to the instance.
               
               To create an instance configuration that includes the custom setup from an instance's boot volume, you must first create a custom image from the instance (see [CreateImage](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Image/CreateImage)). Then, use the custom image to launch a new instance (see [LaunchInstance](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstance)). Finally, create the instance configuration based on the instance that you created from the custom image.
               
               To include block volume contents with an instance configuration, first create a backup of the attached block volumes (see [CreateVolumeBackup](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/VolumeBackup/CreateVolumeBackup)). Then, create the instance configuration by specifying the list of settings, using [InstanceConfigurationVolumeSourceFromVolumeBackupDetails](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/datatypes/InstanceConfigurationVolumeSourceFromVolumeBackupDetails) to include the block volume backups in the list of settings.
               
               The following values are supported:
        :param pulumi.Input[str] time_created: The date and time the instance configuration was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).  Example: `2016-08-25T21:10:29.600Z`
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if deferred_fields is not None:
            pulumi.set(__self__, "deferred_fields", deferred_fields)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if instance_details is not None:
            pulumi.set(__self__, "instance_details", instance_details)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if source is not None:
            pulumi.set(__self__, "source", source)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the compartment containing the instance. Instances created from instance configurations are placed in the same compartment as the instance that was used to create the instance configuration.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="deferredFields")
    def deferred_fields(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Parameters that were not specified when the instance configuration was created, but that are required to launch an instance from the instance configuration. See the [LaunchInstanceConfiguration](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstanceConfiguration) operation.
        """
        return pulumi.get(self, "deferred_fields")

    @deferred_fields.setter
    def deferred_fields(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "deferred_fields", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="instanceDetails")
    def instance_details(self) -> Optional[pulumi.Input['InstanceConfigurationInstanceDetailsArgs']]:
        return pulumi.get(self, "instance_details")

    @instance_details.setter
    def instance_details(self, value: Optional[pulumi.Input['InstanceConfigurationInstanceDetailsArgs']]):
        pulumi.set(self, "instance_details", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance to use to create the instance configuration.
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input[str]]:
        """
        The source of the instance configuration. An instance configuration defines the settings to use when creating Compute instances, including details such as the base image, shape, and metadata. You can also specify the associated resources for the instance, such as block volume attachments and network configuration.

        When you create an instance configuration using an existing instance as a template, the instance configuration does not include any information from the source instance's boot volume, such as installed applications, binaries, and files on the instance. It also does not include the contents of any block volumes that are attached to the instance.

        To create an instance configuration that includes the custom setup from an instance's boot volume, you must first create a custom image from the instance (see [CreateImage](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Image/CreateImage)). Then, use the custom image to launch a new instance (see [LaunchInstance](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstance)). Finally, create the instance configuration based on the instance that you created from the custom image.

        To include block volume contents with an instance configuration, first create a backup of the attached block volumes (see [CreateVolumeBackup](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/VolumeBackup/CreateVolumeBackup)). Then, create the instance configuration by specifying the list of settings, using [InstanceConfigurationVolumeSourceFromVolumeBackupDetails](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/datatypes/InstanceConfigurationVolumeSourceFromVolumeBackupDetails) to include the block volume backups in the list of settings.

        The following values are supported:
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time the instance configuration was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).  Example: `2016-08-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)


class InstanceConfiguration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 instance_details: Optional[pulumi.Input[pulumi.InputType['InstanceConfigurationInstanceDetailsArgs']]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Instance Configuration resource in Oracle Cloud Infrastructure Core service.

        Creates an instance configuration. An instance configuration is a template that defines the
        settings to use when creating Compute instances.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_instance_configuration = oci.core.InstanceConfiguration("testInstanceConfiguration",
            compartment_id=var["compartment_id"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            display_name=var["instance_configuration_display_name"],
            freeform_tags={
                "Department": "Finance",
            },
            instance_details=oci.core.InstanceConfigurationInstanceDetailsArgs(
                instance_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                block_volumes=[oci.core.InstanceConfigurationInstanceDetailsBlockVolumeArgs(
                    attach_details=oci.core.InstanceConfigurationInstanceDetailsBlockVolumeAttachDetailsArgs(
                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        device=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_pv_encryption_in_transit_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_read_only=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_shareable=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        use_chap=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    create_details=oci.core.InstanceConfigurationInstanceDetailsBlockVolumeCreateDetailsArgs(
                        autotune_policies=[oci.core.InstanceConfigurationInstanceDetailsBlockVolumeCreateDetailsAutotunePolicyArgs(
                            autotune_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            max_vpus_per_gb=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        )],
                        availability_domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        backup_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        defined_tags={
                            "Operations.CostCenter": "42",
                        },
                        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        freeform_tags={
                            "Department": "Finance",
                        },
                        kms_key_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        size_in_gbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        source_details=oci.core.InstanceConfigurationInstanceDetailsBlockVolumeCreateDetailsSourceDetailsArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        vpus_per_gb=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    volume_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                launch_details=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsArgs(
                    agent_config=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsAgentConfigArgs(
                        are_all_plugins_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_management_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_monitoring_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        plugins_configs=[oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsAgentConfigPluginsConfigArgs(
                            desired_state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        )],
                    ),
                    availability_config=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsAvailabilityConfigArgs(
                        recovery_action=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    availability_domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    capacity_reservation_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    create_vnic_details=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsCreateVnicDetailsArgs(
                        assign_private_dns_record=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        assign_public_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        defined_tags={
                            "Operations.CostCenter": "42",
                        },
                        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        freeform_tags={
                            "Department": "Finance",
                        },
                        hostname_label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        nsg_ids=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        private_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        skip_source_dest_check=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        subnet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    dedicated_vm_host_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    defined_tags={
                        "Operations.CostCenter": "42",
                    },
                    display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    extended_metadata=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    fault_domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    freeform_tags={
                        "Department": "Finance",
                    },
                    instance_options=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsInstanceOptionsArgs(
                        are_legacy_imds_endpoints_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    ipxe_script=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    is_pv_encryption_in_transit_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    launch_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    launch_options=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsLaunchOptionsArgs(
                        boot_volume_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        firmware=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_consistent_volume_naming_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_pv_encryption_in_transit_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        network_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        remote_data_volume_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    metadata=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    platform_config=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsPlatformConfigArgs(
                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        are_virtual_instructions_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_access_control_service_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_input_output_memory_management_unit_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_measured_boot_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_memory_encryption_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_secure_boot_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_symmetric_multi_threading_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_trusted_platform_module_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        numa_nodes_per_socket=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        percentage_of_cores_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    preemptible_instance_config=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsPreemptibleInstanceConfigArgs(
                        preemption_action=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsPreemptibleInstanceConfigPreemptionActionArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            preserve_boot_volume=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    ),
                    preferred_maintenance_action=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    shape=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    shape_config=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsShapeConfigArgs(
                        baseline_ocpu_utilization=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        memory_in_gbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        nvmes=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ocpus=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    source_details=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsSourceDetailsArgs(
                        source_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        boot_volume_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        boot_volume_size_in_gbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        boot_volume_vpus_per_gb=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        image_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                ),
                secondary_vnics=[oci.core.InstanceConfigurationInstanceDetailsSecondaryVnicArgs(
                    create_vnic_details=oci.core.InstanceConfigurationInstanceDetailsSecondaryVnicCreateVnicDetailsArgs(
                        assign_private_dns_record=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        assign_public_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        defined_tags={
                            "Operations.CostCenter": "42",
                        },
                        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        freeform_tags={
                            "Department": "Finance",
                        },
                        hostname_label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        nsg_ids=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        private_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        skip_source_dest_check=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        subnet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    nic_index=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
            ),
            instance_id=oci_core_instance["test_instance"]["id"],
            source=var["instance_configuration_source"])
        ```

        ## Import

        InstanceConfigurations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Core/instanceConfiguration:InstanceConfiguration test_instance_configuration "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment containing the instance. Instances created from instance configurations are placed in the same compartment as the instance that was used to create the instance configuration.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] instance_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance to use to create the instance configuration.
        :param pulumi.Input[str] source: The source of the instance configuration. An instance configuration defines the settings to use when creating Compute instances, including details such as the base image, shape, and metadata. You can also specify the associated resources for the instance, such as block volume attachments and network configuration.
               
               When you create an instance configuration using an existing instance as a template, the instance configuration does not include any information from the source instance's boot volume, such as installed applications, binaries, and files on the instance. It also does not include the contents of any block volumes that are attached to the instance.
               
               To create an instance configuration that includes the custom setup from an instance's boot volume, you must first create a custom image from the instance (see [CreateImage](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Image/CreateImage)). Then, use the custom image to launch a new instance (see [LaunchInstance](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstance)). Finally, create the instance configuration based on the instance that you created from the custom image.
               
               To include block volume contents with an instance configuration, first create a backup of the attached block volumes (see [CreateVolumeBackup](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/VolumeBackup/CreateVolumeBackup)). Then, create the instance configuration by specifying the list of settings, using [InstanceConfigurationVolumeSourceFromVolumeBackupDetails](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/datatypes/InstanceConfigurationVolumeSourceFromVolumeBackupDetails) to include the block volume backups in the list of settings.
               
               The following values are supported:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceConfigurationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Instance Configuration resource in Oracle Cloud Infrastructure Core service.

        Creates an instance configuration. An instance configuration is a template that defines the
        settings to use when creating Compute instances.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_instance_configuration = oci.core.InstanceConfiguration("testInstanceConfiguration",
            compartment_id=var["compartment_id"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            display_name=var["instance_configuration_display_name"],
            freeform_tags={
                "Department": "Finance",
            },
            instance_details=oci.core.InstanceConfigurationInstanceDetailsArgs(
                instance_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                block_volumes=[oci.core.InstanceConfigurationInstanceDetailsBlockVolumeArgs(
                    attach_details=oci.core.InstanceConfigurationInstanceDetailsBlockVolumeAttachDetailsArgs(
                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        device=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_pv_encryption_in_transit_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_read_only=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_shareable=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        use_chap=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    create_details=oci.core.InstanceConfigurationInstanceDetailsBlockVolumeCreateDetailsArgs(
                        autotune_policies=[oci.core.InstanceConfigurationInstanceDetailsBlockVolumeCreateDetailsAutotunePolicyArgs(
                            autotune_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            max_vpus_per_gb=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        )],
                        availability_domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        backup_policy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        defined_tags={
                            "Operations.CostCenter": "42",
                        },
                        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        freeform_tags={
                            "Department": "Finance",
                        },
                        kms_key_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        size_in_gbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        source_details=oci.core.InstanceConfigurationInstanceDetailsBlockVolumeCreateDetailsSourceDetailsArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        vpus_per_gb=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    volume_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                launch_details=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsArgs(
                    agent_config=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsAgentConfigArgs(
                        are_all_plugins_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_management_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_monitoring_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        plugins_configs=[oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsAgentConfigPluginsConfigArgs(
                            desired_state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        )],
                    ),
                    availability_config=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsAvailabilityConfigArgs(
                        recovery_action=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    availability_domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    capacity_reservation_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    create_vnic_details=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsCreateVnicDetailsArgs(
                        assign_private_dns_record=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        assign_public_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        defined_tags={
                            "Operations.CostCenter": "42",
                        },
                        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        freeform_tags={
                            "Department": "Finance",
                        },
                        hostname_label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        nsg_ids=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        private_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        skip_source_dest_check=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        subnet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    dedicated_vm_host_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    defined_tags={
                        "Operations.CostCenter": "42",
                    },
                    display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    extended_metadata=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    fault_domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    freeform_tags={
                        "Department": "Finance",
                    },
                    instance_options=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsInstanceOptionsArgs(
                        are_legacy_imds_endpoints_disabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    ipxe_script=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    is_pv_encryption_in_transit_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    launch_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    launch_options=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsLaunchOptionsArgs(
                        boot_volume_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        firmware=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_consistent_volume_naming_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_pv_encryption_in_transit_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        network_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        remote_data_volume_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    metadata=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    platform_config=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsPlatformConfigArgs(
                        type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        are_virtual_instructions_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_access_control_service_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_input_output_memory_management_unit_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_measured_boot_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_memory_encryption_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_secure_boot_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_symmetric_multi_threading_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_trusted_platform_module_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        numa_nodes_per_socket=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        percentage_of_cores_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    preemptible_instance_config=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsPreemptibleInstanceConfigArgs(
                        preemption_action=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsPreemptibleInstanceConfigPreemptionActionArgs(
                            type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            preserve_boot_volume=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                    ),
                    preferred_maintenance_action=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    shape=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    shape_config=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsShapeConfigArgs(
                        baseline_ocpu_utilization=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        memory_in_gbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        nvmes=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ocpus=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    source_details=oci.core.InstanceConfigurationInstanceDetailsLaunchDetailsSourceDetailsArgs(
                        source_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        boot_volume_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        boot_volume_size_in_gbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        boot_volume_vpus_per_gb=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        image_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                ),
                secondary_vnics=[oci.core.InstanceConfigurationInstanceDetailsSecondaryVnicArgs(
                    create_vnic_details=oci.core.InstanceConfigurationInstanceDetailsSecondaryVnicCreateVnicDetailsArgs(
                        assign_private_dns_record=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        assign_public_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        defined_tags={
                            "Operations.CostCenter": "42",
                        },
                        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        freeform_tags={
                            "Department": "Finance",
                        },
                        hostname_label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        nsg_ids=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        private_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        skip_source_dest_check=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        subnet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    nic_index=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
            ),
            instance_id=oci_core_instance["test_instance"]["id"],
            source=var["instance_configuration_source"])
        ```

        ## Import

        InstanceConfigurations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Core/instanceConfiguration:InstanceConfiguration test_instance_configuration "id"
        ```

        :param str resource_name: The name of the resource.
        :param InstanceConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 instance_details: Optional[pulumi.Input[pulumi.InputType['InstanceConfigurationInstanceDetailsArgs']]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 source: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceConfigurationArgs.__new__(InstanceConfigurationArgs)

            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["freeform_tags"] = freeform_tags
            __props__.__dict__["instance_details"] = instance_details
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["source"] = source
            __props__.__dict__["deferred_fields"] = None
            __props__.__dict__["time_created"] = None
        super(InstanceConfiguration, __self__).__init__(
            'oci:Core/instanceConfiguration:InstanceConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            deferred_fields: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            instance_details: Optional[pulumi.Input[pulumi.InputType['InstanceConfigurationInstanceDetailsArgs']]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            source: Optional[pulumi.Input[str]] = None,
            time_created: Optional[pulumi.Input[str]] = None) -> 'InstanceConfiguration':
        """
        Get an existing InstanceConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: The OCID of the compartment containing the instance. Instances created from instance configurations are placed in the same compartment as the instance that was used to create the instance configuration.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] deferred_fields: Parameters that were not specified when the instance configuration was created, but that are required to launch an instance from the instance configuration. See the [LaunchInstanceConfiguration](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstanceConfiguration) operation.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] instance_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance to use to create the instance configuration.
        :param pulumi.Input[str] source: The source of the instance configuration. An instance configuration defines the settings to use when creating Compute instances, including details such as the base image, shape, and metadata. You can also specify the associated resources for the instance, such as block volume attachments and network configuration.
               
               When you create an instance configuration using an existing instance as a template, the instance configuration does not include any information from the source instance's boot volume, such as installed applications, binaries, and files on the instance. It also does not include the contents of any block volumes that are attached to the instance.
               
               To create an instance configuration that includes the custom setup from an instance's boot volume, you must first create a custom image from the instance (see [CreateImage](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Image/CreateImage)). Then, use the custom image to launch a new instance (see [LaunchInstance](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstance)). Finally, create the instance configuration based on the instance that you created from the custom image.
               
               To include block volume contents with an instance configuration, first create a backup of the attached block volumes (see [CreateVolumeBackup](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/VolumeBackup/CreateVolumeBackup)). Then, create the instance configuration by specifying the list of settings, using [InstanceConfigurationVolumeSourceFromVolumeBackupDetails](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/datatypes/InstanceConfigurationVolumeSourceFromVolumeBackupDetails) to include the block volume backups in the list of settings.
               
               The following values are supported:
        :param pulumi.Input[str] time_created: The date and time the instance configuration was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).  Example: `2016-08-25T21:10:29.600Z`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceConfigurationState.__new__(_InstanceConfigurationState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["deferred_fields"] = deferred_fields
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["instance_details"] = instance_details
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["source"] = source
        __props__.__dict__["time_created"] = time_created
        return InstanceConfiguration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        The OCID of the compartment containing the instance. Instances created from instance configurations are placed in the same compartment as the instance that was used to create the instance configuration.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="deferredFields")
    def deferred_fields(self) -> pulumi.Output[Sequence[str]]:
        """
        Parameters that were not specified when the instance configuration was created, but that are required to launch an instance from the instance configuration. See the [LaunchInstanceConfiguration](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstanceConfiguration) operation.
        """
        return pulumi.get(self, "deferred_fields")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="instanceDetails")
    def instance_details(self) -> pulumi.Output['outputs.InstanceConfigurationInstanceDetails']:
        return pulumi.get(self, "instance_details")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the instance to use to create the instance configuration.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def source(self) -> pulumi.Output[str]:
        """
        The source of the instance configuration. An instance configuration defines the settings to use when creating Compute instances, including details such as the base image, shape, and metadata. You can also specify the associated resources for the instance, such as block volume attachments and network configuration.

        When you create an instance configuration using an existing instance as a template, the instance configuration does not include any information from the source instance's boot volume, such as installed applications, binaries, and files on the instance. It also does not include the contents of any block volumes that are attached to the instance.

        To create an instance configuration that includes the custom setup from an instance's boot volume, you must first create a custom image from the instance (see [CreateImage](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Image/CreateImage)). Then, use the custom image to launch a new instance (see [LaunchInstance](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstance)). Finally, create the instance configuration based on the instance that you created from the custom image.

        To include block volume contents with an instance configuration, first create a backup of the attached block volumes (see [CreateVolumeBackup](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/VolumeBackup/CreateVolumeBackup)). Then, create the instance configuration by specifying the list of settings, using [InstanceConfigurationVolumeSourceFromVolumeBackupDetails](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/datatypes/InstanceConfigurationVolumeSourceFromVolumeBackupDetails) to include the block volume backups in the list of settings.

        The following values are supported:
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The date and time the instance configuration was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).  Example: `2016-08-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

