# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetNamespaceStorageEncryptionKeyInfoResult',
    'AwaitableGetNamespaceStorageEncryptionKeyInfoResult',
    'get_namespace_storage_encryption_key_info',
    'get_namespace_storage_encryption_key_info_output',
]

@pulumi.output_type
class GetNamespaceStorageEncryptionKeyInfoResult:
    """
    A collection of values returned by getNamespaceStorageEncryptionKeyInfo.
    """
    def __init__(__self__, id=None, items=None, namespace=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if items and not isinstance(items, list):
            raise TypeError("Expected argument 'items' to be a list")
        pulumi.set(__self__, "items", items)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetNamespaceStorageEncryptionKeyInfoItemResult']:
        """
        This is an array of encryption key info. There are at most 2 items in the list.
        """
        return pulumi.get(self, "items")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        return pulumi.get(self, "namespace")


class AwaitableGetNamespaceStorageEncryptionKeyInfoResult(GetNamespaceStorageEncryptionKeyInfoResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNamespaceStorageEncryptionKeyInfoResult(
            id=self.id,
            items=self.items,
            namespace=self.namespace)


def get_namespace_storage_encryption_key_info(namespace: Optional[str] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNamespaceStorageEncryptionKeyInfoResult:
    """
    This data source provides details about a specific Namespace Storage Encryption Key Info resource in Oracle Cloud Infrastructure Log Analytics service.

    This API returns the list of customer owned encryption key info.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_namespace_storage_encryption_key_info = oci.LogAnalytics.get_namespace_storage_encryption_key_info(namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str namespace: The Logging Analytics namespace used for the request.
    """
    __args__ = dict()
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:LogAnalytics/getNamespaceStorageEncryptionKeyInfo:getNamespaceStorageEncryptionKeyInfo', __args__, opts=opts, typ=GetNamespaceStorageEncryptionKeyInfoResult).value

    return AwaitableGetNamespaceStorageEncryptionKeyInfoResult(
        id=__ret__.id,
        items=__ret__.items,
        namespace=__ret__.namespace)


@_utilities.lift_output_func(get_namespace_storage_encryption_key_info)
def get_namespace_storage_encryption_key_info_output(namespace: Optional[pulumi.Input[str]] = None,
                                                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNamespaceStorageEncryptionKeyInfoResult]:
    """
    This data source provides details about a specific Namespace Storage Encryption Key Info resource in Oracle Cloud Infrastructure Log Analytics service.

    This API returns the list of customer owned encryption key info.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_namespace_storage_encryption_key_info = oci.LogAnalytics.get_namespace_storage_encryption_key_info(namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str namespace: The Logging Analytics namespace used for the request.
    """
    ...
