# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetReportContentResult',
    'AwaitableGetReportContentResult',
    'get_report_content',
    'get_report_content_output',
]

@pulumi.output_type
class GetReportContentResult:
    """
    A collection of values returned by getReportContent.
    """
    def __init__(__self__, id=None, report_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if report_id and not isinstance(report_id, str):
            raise TypeError("Expected argument 'report_id' to be a str")
        pulumi.set(__self__, "report_id", report_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="reportId")
    def report_id(self) -> str:
        return pulumi.get(self, "report_id")


class AwaitableGetReportContentResult(GetReportContentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetReportContentResult(
            id=self.id,
            report_id=self.report_id)


def get_report_content(report_id: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetReportContentResult:
    """
    This data source provides details about a specific Report Content resource in Oracle Cloud Infrastructure Data Safe service.

    Downloads the specified report in the form of PDF or XLXS.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_report_content = oci.DataSafe.get_report_content(report_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str report_id: Unique report identifier
    """
    __args__ = dict()
    __args__['reportId'] = report_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getReportContent:getReportContent', __args__, opts=opts, typ=GetReportContentResult).value

    return AwaitableGetReportContentResult(
        id=__ret__.id,
        report_id=__ret__.report_id)


@_utilities.lift_output_func(get_report_content)
def get_report_content_output(report_id: Optional[pulumi.Input[str]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetReportContentResult]:
    """
    This data source provides details about a specific Report Content resource in Oracle Cloud Infrastructure Data Safe service.

    Downloads the specified report in the form of PDF or XLXS.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_report_content = oci.DataSafe.get_report_content(report_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str report_id: Unique report identifier
    """
    ...
