# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCpesResult',
    'AwaitableGetCpesResult',
    'get_cpes',
    'get_cpes_output',
]

@pulumi.output_type
class GetCpesResult:
    """
    A collection of values returned by getCpes.
    """
    def __init__(__self__, compartment_id=None, cpes=None, filters=None, id=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if cpes and not isinstance(cpes, list):
            raise TypeError("Expected argument 'cpes' to be a list")
        pulumi.set(__self__, "cpes", cpes)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the CPE.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def cpes(self) -> Sequence['outputs.GetCpesCpeResult']:
        """
        The list of cpes.
        """
        return pulumi.get(self, "cpes")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetCpesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetCpesResult(GetCpesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCpesResult(
            compartment_id=self.compartment_id,
            cpes=self.cpes,
            filters=self.filters,
            id=self.id)


def get_cpes(compartment_id: Optional[str] = None,
             filters: Optional[Sequence[pulumi.InputType['GetCpesFilterArgs']]] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCpesResult:
    """
    This data source provides the list of Cpes in Oracle Cloud Infrastructure Core service.

    Lists the customer-premises equipment objects (CPEs) in the specified compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_cpes = oci.Core.get_cpes(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getCpes:getCpes', __args__, opts=opts, typ=GetCpesResult).value

    return AwaitableGetCpesResult(
        compartment_id=__ret__.compartment_id,
        cpes=__ret__.cpes,
        filters=__ret__.filters,
        id=__ret__.id)


@_utilities.lift_output_func(get_cpes)
def get_cpes_output(compartment_id: Optional[pulumi.Input[str]] = None,
                    filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetCpesFilterArgs']]]]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetCpesResult]:
    """
    This data source provides the list of Cpes in Oracle Cloud Infrastructure Core service.

    Lists the customer-premises equipment objects (CPEs) in the specified compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_cpes = oci.Core.get_cpes(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    """
    ...
