# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetManagedDatabaseSqlTuningAdvisorTasksRecommendationResult',
    'AwaitableGetManagedDatabaseSqlTuningAdvisorTasksRecommendationResult',
    'get_managed_database_sql_tuning_advisor_tasks_recommendation',
    'get_managed_database_sql_tuning_advisor_tasks_recommendation_output',
]

@pulumi.output_type
class GetManagedDatabaseSqlTuningAdvisorTasksRecommendationResult:
    """
    A collection of values returned by getManagedDatabaseSqlTuningAdvisorTasksRecommendation.
    """
    def __init__(__self__, execution_id=None, id=None, items=None, managed_database_id=None, sql_object_id=None, sql_tuning_advisor_task_id=None):
        if execution_id and not isinstance(execution_id, str):
            raise TypeError("Expected argument 'execution_id' to be a str")
        pulumi.set(__self__, "execution_id", execution_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if items and not isinstance(items, list):
            raise TypeError("Expected argument 'items' to be a list")
        pulumi.set(__self__, "items", items)
        if managed_database_id and not isinstance(managed_database_id, str):
            raise TypeError("Expected argument 'managed_database_id' to be a str")
        pulumi.set(__self__, "managed_database_id", managed_database_id)
        if sql_object_id and not isinstance(sql_object_id, str):
            raise TypeError("Expected argument 'sql_object_id' to be a str")
        pulumi.set(__self__, "sql_object_id", sql_object_id)
        if sql_tuning_advisor_task_id and not isinstance(sql_tuning_advisor_task_id, str):
            raise TypeError("Expected argument 'sql_tuning_advisor_task_id' to be a str")
        pulumi.set(__self__, "sql_tuning_advisor_task_id", sql_tuning_advisor_task_id)

    @property
    @pulumi.getter(name="executionId")
    def execution_id(self) -> str:
        return pulumi.get(self, "execution_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetManagedDatabaseSqlTuningAdvisorTasksRecommendationItemResult']:
        """
        A list of SQL Tuning Advisor recommendations.
        """
        return pulumi.get(self, "items")

    @property
    @pulumi.getter(name="managedDatabaseId")
    def managed_database_id(self) -> str:
        return pulumi.get(self, "managed_database_id")

    @property
    @pulumi.getter(name="sqlObjectId")
    def sql_object_id(self) -> str:
        return pulumi.get(self, "sql_object_id")

    @property
    @pulumi.getter(name="sqlTuningAdvisorTaskId")
    def sql_tuning_advisor_task_id(self) -> str:
        """
        The unique identifier of the task. This is not the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "sql_tuning_advisor_task_id")


class AwaitableGetManagedDatabaseSqlTuningAdvisorTasksRecommendationResult(GetManagedDatabaseSqlTuningAdvisorTasksRecommendationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetManagedDatabaseSqlTuningAdvisorTasksRecommendationResult(
            execution_id=self.execution_id,
            id=self.id,
            items=self.items,
            managed_database_id=self.managed_database_id,
            sql_object_id=self.sql_object_id,
            sql_tuning_advisor_task_id=self.sql_tuning_advisor_task_id)


def get_managed_database_sql_tuning_advisor_tasks_recommendation(execution_id: Optional[str] = None,
                                                                 managed_database_id: Optional[str] = None,
                                                                 sql_object_id: Optional[str] = None,
                                                                 sql_tuning_advisor_task_id: Optional[str] = None,
                                                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetManagedDatabaseSqlTuningAdvisorTasksRecommendationResult:
    """
    This data source provides details about a specific Managed Database Sql Tuning Advisor Tasks Recommendation resource in Oracle Cloud Infrastructure Database Management service.

    Gets the findings and possible actions for a given object in a SQL tuning task.
    The task ID and object ID are used to retrieve the findings and recommendations.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_managed_database_sql_tuning_advisor_tasks_recommendation = oci.DatabaseManagement.get_managed_database_sql_tuning_advisor_tasks_recommendation(execution_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        managed_database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sql_object_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sql_tuning_advisor_task_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str execution_id: The execution ID for an execution of a SQL tuning task. This is not the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str managed_database_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Managed Database.
    :param str sql_object_id: The SQL object ID for the SQL tuning task. This is not the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str sql_tuning_advisor_task_id: The SQL tuning task identifier. This is not the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    __args__ = dict()
    __args__['executionId'] = execution_id
    __args__['managedDatabaseId'] = managed_database_id
    __args__['sqlObjectId'] = sql_object_id
    __args__['sqlTuningAdvisorTaskId'] = sql_tuning_advisor_task_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DatabaseManagement/getManagedDatabaseSqlTuningAdvisorTasksRecommendation:getManagedDatabaseSqlTuningAdvisorTasksRecommendation', __args__, opts=opts, typ=GetManagedDatabaseSqlTuningAdvisorTasksRecommendationResult).value

    return AwaitableGetManagedDatabaseSqlTuningAdvisorTasksRecommendationResult(
        execution_id=__ret__.execution_id,
        id=__ret__.id,
        items=__ret__.items,
        managed_database_id=__ret__.managed_database_id,
        sql_object_id=__ret__.sql_object_id,
        sql_tuning_advisor_task_id=__ret__.sql_tuning_advisor_task_id)


@_utilities.lift_output_func(get_managed_database_sql_tuning_advisor_tasks_recommendation)
def get_managed_database_sql_tuning_advisor_tasks_recommendation_output(execution_id: Optional[pulumi.Input[str]] = None,
                                                                        managed_database_id: Optional[pulumi.Input[str]] = None,
                                                                        sql_object_id: Optional[pulumi.Input[str]] = None,
                                                                        sql_tuning_advisor_task_id: Optional[pulumi.Input[str]] = None,
                                                                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetManagedDatabaseSqlTuningAdvisorTasksRecommendationResult]:
    """
    This data source provides details about a specific Managed Database Sql Tuning Advisor Tasks Recommendation resource in Oracle Cloud Infrastructure Database Management service.

    Gets the findings and possible actions for a given object in a SQL tuning task.
    The task ID and object ID are used to retrieve the findings and recommendations.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_managed_database_sql_tuning_advisor_tasks_recommendation = oci.DatabaseManagement.get_managed_database_sql_tuning_advisor_tasks_recommendation(execution_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        managed_database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sql_object_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sql_tuning_advisor_task_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str execution_id: The execution ID for an execution of a SQL tuning task. This is not the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str managed_database_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Managed Database.
    :param str sql_object_id: The SQL object ID for the SQL tuning task. This is not the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str sql_tuning_advisor_task_id: The SQL tuning task identifier. This is not the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    """
    ...
